      SUBROUTINE bgcbio
#if defined key_top
!CC   ------------------------------------------------------------------
!CC   
!CC   ROUTINE bgcbio : DGOM MODEL
!CC   *****************************
!CC   
!C
!C     PURPOSE.
!C     --------
!C          ECOSYSTEM MODEL
!C
!C     EXTERNALS.
!C     ----------
!C          NONE.
!C
!C   MODIFICATIONS:
!C   --------------
!C      original      : 2001    O. Aumont
!C      modifications : 2002    E. Buitenhuis
!C ---------------------------------------------------------------------
      USE trc
      USE trp_trc
      USE sms
      USE oce_trc
      USE lbclnk
      USE lib_mpp
      IMPLICIT NONE
! local declarations
      INTEGER ji, jj, jk, jl, jm, jn, ik
      REAL degn2o,deln2o,dumn2o,duon2o,nitrif,oxygen,n2fix,prbn2s
      REAL consum,nitrfac,denno3,loscal
      REAL pres,prodt,proalk
      REAL grma2a(jpi,jpj,jpk)
      REAL grme2a(jpi,jpj,jpk)
      REAL grmi2a(jpi,jpj,jpk)
!
      REAL zgrdmp
!
      REAL(wp) total(jptra), totaf(jptra), totoc, totof, units
      real sisum,fesum
!
#  include "domzgr_substitute.h90"
!
! Initialisation of variables
! ------------------------------------------------------------------
!
      sisum=0.
      fesum=0.
      DO jj = 2, nlcj-1
        DO ji = 2, nlci-1
!
! Iron and Si deposition at the surface
! the dust variable is in kgdust/m2/s (from Jickells et al. 2005). 
! We use 0.035gFe/gdust, 0.308 gSi/gdust (or 8.8gSi/gFe). 
! The solubility of Fe in dust is rn_fersol (usually 2%, set in namelist). 
! The solubility of Si in dust is 7.5%. 
! Variables irondep and sidep are in mol/L/time_step for Fe and Si, respectivel
! The molecular weight of Fe and Si is 55.85 and 28.01, respectively.
!
! from Mahowald et al 2009 
! the dust variable is in ngFe(soluble)/m2/s
! We use 8.8gSi/gFe (0.308/0.035).
! rn_fersol (set in namelist) should be = 1 and is used as a scaling factor.
! The solubility of Si in dust is 7.5%. We use a mean solubility of Fe of
!                                 1.25% to scale the Si flux.
! -------------------------------------------------------------------
!
!J          irondep(ji,jj,1) = dust(ji,jj)*0.035*rn_fersol*rfact/        &
!J     &                                       (fse3t(ji,jj,1)*55.85) 
!J          sidep(ji,jj,1) = dust(ji,jj)*0.308*0.075*rfact/              &
!J     &                                       (fse3t(ji,jj,1)*28.01) 

            irondep(ji,jj,1) = dust(ji,jj)*rn_fersol*rfact/        &
     &                                       (fse3t(ji,jj,1)*55.85) 
            if ( rn_fersol .gt. .999 ) then
                    sidep(ji,jj,1) = irondep(ji,jj,1)*             &
     &                   (0.308/0.035)*(0.075/0.0125)*(55.85/28.01)
            else 
                 sidep(ji,jj,1)=irondep(ji,jj,1)*                     &
     &                (0.308/0.035)*(0.075/rn_fersol)* (55.85/28.01)
            endif
         sisum=sisum+sidep(ji,jj,1)
         fesum=fesum+irondep(ji,jj,1)
        END DO
      END DO
      if ( lk_mpp ) then 
          call mpp_sum(sisum)
          call mpp_sum(fesum )
      endif
      if ( lwp ) then
        write(numout,*) ' Iron deposition ', fesum
        write( numout, *) 'silica deposiiton ', sisum
      endif
!
! Call optical /production routine to compute phytoplankton growth rate
! over the global ocean. Growth rates for each element are 
! computed (C, Si, Fe, Chl)
! -------------------------------------------------------------------
!
      CALL bgcpro
!
! Calculate loss rates
! -------------------------------------------------------------------
!     
      CALL bgclos
!
! Call subroutine for computation of the vertical flux 
! of particulate organic matter
! -------------------------------------------------------------------
!
      CALL bgcsnk
!
! pre-compute concentration changes of the (rapidly
! varying) tracers for preventing them to fall below 0
! -------------------------------------------------------------------
!
      CALL bgcnul
!
! Recompute the SMS related to zooplankton grazing
! -------------------------------------------------------------------
!
      trc2d(:,:,17) = 0.
      trc2d(:,:,26) = 0.
      DO jk = 1, jpk-1
        DO jj = 2, nlcj-1
          DO ji = 2, nlci-1
!
            gramit(ji,jj,jk) = grabac(ji,jj,jk)+grazg(ji,jj,jk)        &
     &        +grazm(ji,jj,jk)
!
            grmi2a(ji,jj,jk) = grabac(ji,jj,jk)*ferat3+                &
     &          grazgf(ji,jj,jk)+grazmf(ji,jj,jk)
! 
            gramet(ji,jj,jk) = grazbac(ji,jj,jk)+ grazz(ji,jj,jk) +    &
     &          grazpoc(ji,jj,jk)+grazgoc(ji,jj,jk)
!
            grme2a(ji,jj,jk) = grazz(ji,jj,jk)*ferat3+grazbac(ji,jj,jk)*ferat3 &
     &        +grazpof(ji,jj,jk)+grazgof(ji,jj,jk)
   
            gramat(ji,jj,jk) = gramam(ji,jj,jk)+gramaz(ji,jj,jk)       &
     &        +grampoc(ji,jj,jk)+gramgoc(ji,jj,jk)+grambac(ji,jj,jk)
!
            grma2a(ji,jj,jk) =                                         &
     &        (gramam(ji,jj,jk)+gramaz(ji,jj,jk)+grambac(ji,jj,jk))*ferat3  &
     &        +grampof(ji,jj,jk)+gramgof(ji,jj,jk)
!
! assign grazing to organic matter 
! 
            grapoc(ji,jj,jk) = 0.
!
            DO jl = jpdia, jpdia+jppft-1
!
              gramit(ji,jj,jk) = gramit(ji,jj,jk)+gramic(ji,jj,jk,jl,1)
              grmi2a(ji,jj,jk) = grmi2a(ji,jj,jk)+gramic(ji,jj,jk,jl,2)
!    
              gramet(ji,jj,jk) = gramet(ji,jj,jk)+grames(ji,jj,jk,jl,1)
              grme2a(ji,jj,jk) = grme2a(ji,jj,jk)+grames(ji,jj,jk,jl,2)
! 
              gramat(ji,jj,jk) = gramat(ji,jj,jk)+gramac(ji,jj,jk,jl,1)
              grma2a(ji,jj,jk) = grma2a(ji,jj,jk)+gramac(ji,jj,jk,jl,2)
!
            END DO
!
! calculate unassimilated fraction of grazing
!
            mesoge(ji,jj,jk) = min(1.-rn_unames,                       &
     &        rn_ggemes+respz2(ji,jj,jk)/max(rtrn,gramet(ji,jj,jk)),   &
     &        grme2a(ji,jj,jk)*(1.-rn_unames)/max(gramet(ji,jj,jk)*ferat3,minfer))         
!
            micrge(ji,jj,jk) = min(1.-rn_unamic,                       &
     &        rn_ggemic+tn(ji,jj,jk)*rn_ggtmic+respz(ji,jj,jk)/max(rtrn,gramit(ji,jj,jk)),    &
     &        grmi2a(ji,jj,jk)*(1.-rn_unamic)/max(gramit(ji,jj,jk)*ferat3,minfer))          
!
            grafer(ji,jj,jk) = grmi2a(ji,jj,jk)                        &
     &        *(1.-rn_unamic)-ferat3*micrge(ji,jj,jk)*gramit(ji,jj,jk)
!
            macrge(ji,jj,jk) = min(1.-rn_unamac,                       &
     &        rn_ggemac+respz3(ji,jj,jk)/max(rtrn,gramat(ji,jj,jk)),   &
     &        grma2a(ji,jj,jk)*(1.-rn_unamac)/max(gramat(ji,jj,jk)*ferat3,minfer))
!
            bactge(ji,jj,jk) = min(bactge(ji,jj,jk),                   &
     &        (ubafer(ji,jj,jk)+ofer(ji,jj,jk)+ofer2(ji,jj,jk))        &
     &        /max((olimi(ji,jj,jk)+orem(ji,jj,jk)+orem2(ji,jj,jk))    &
     &        *ferat3,minfer))
!

            grarem(ji,jj,jk) = gramit(ji,jj,jk)*(1.-micrge(ji,jj,jk)-rn_unamic)
!
            grapoc(ji,jj,jk) = grapoc(ji,jj,jk)+gramit(ji,jj,jk)*rn_unamic
!
            grarem2(ji,jj,jk) = gramet(ji,jj,jk)*(1.-mesoge(ji,jj,jk)-rn_unames)
!
            grafer2(ji,jj,jk) = grme2a(ji,jj,jk)                       &
     &        *(1.-rn_unames)-ferat3*mesoge(ji,jj,jk)*gramet(ji,jj,jk)
!
            grapoc2(ji,jj,jk) = gramet(ji,jj,jk)*rn_unames
!
            grarem3(ji,jj,jk) = gramat(ji,jj,jk)*(1.-macrge(ji,jj,jk)-rn_unamac)
!
            grafer3(ji,jj,jk) = grma2a(ji,jj,jk)                       &
     &        *(1.-rn_unamac)-ferat3*macrge(ji,jj,jk)*gramat(ji,jj,jk)
!
            grapoc3(ji,jj,jk) = gramat(ji,jj,jk)*rn_unamac
!
! recalculate prodms, prodmd:
!
            DO jl = jpdia, jpdia+jppft-1
!
              zgrdmp = gramic(ji,jj,jk,jl,1)*(1.-micrge(ji,jj,jk))+    &
     &          grames(ji,jj,jk,jl,1)*(1.-mesoge(ji,jj,jk)-rn_assdms(1)*rn_unames)+ &
     &          gramac(ji,jj,jk,jl,1)*(1.-macrge(ji,jj,jk)-rn_assdms(2)*rn_unamac)
!
              prodmd(ji,jj,jk) = prodmd(ji,jj,jk)+((1.-rn_rdddms)*     &
     &          zgrdmp)*rphdmd(ji,jj,jk,jl)
!
              prodms(ji,jj,jk) = prodms(ji,jj,jk)+(rn_rdddms*zgrdmp+   &
     &          rn_xpldmd(jl)*rfact/rjjss*etot(ji,jj,jk)/rn_etomax*    &
     &          trn(ji,jj,jk,jl))*rphdmd(ji,jj,jk,jl)
!
            END DO
!     
! Determination of tracer concentrations as a function of 
! biological sources and sinks
! -------------------------------------------------------------------
!
! Evolution of O2
! ---------------
!
            consum = (1.-bactge(ji,jj,jk))*(olimi(ji,jj,jk)            &
     &        +orem(ji,jj,jk)+orem2(ji,jj,jk))                         &
     &        +grarem(ji,jj,jk)*rn_sigmic                              &
     &        +grarem2(ji,jj,jk)*rn_sigmes                             &
     &        +grarem3(ji,jj,jk)*rn_sigmac                             &
     &        +respz(ji,jj,jk)+respz2(ji,jj,jk)+respz3(ji,jj,jk)       &
     &        +resbac(ji,jj,jk)/3.0
            DO jl = jpdia, jpdia+jppft-1
              consum = consum +resphy(ji,jj,jk,jl,1)
            END DO
!151012 This leads to denitrification in the upper 200m            delo2(ji,jj,jk) = min(rato2c*consum,delo2(ji,jj,jk))
            nitrfac=max(-0.5,(rn_doxden-trno2(ji,jj,jk))            &
     &        /(2*rn_doxden+trno2(ji,jj,jk)))
            nitrfac=(sin(nitrfac*rpi)+1.)/2.
            delo2(ji,jj,jk)=rato2c*consum*(1.-nitrfac)
            denitr(ji,jj,jk) = 0.8*(rato2c*consum-delo2(ji,jj,jk))
           trn(ji,jj,jk,jpn2o)= trn(ji,jj,jk,jpn2o)+denitr(ji,jj,jk)     &
      &      *rn_denn2o
           trc3d(ji,jj,jk,17) = denitr(ji,jj,jk)*rn_denn2o*rfactr*1e3
           trn(ji,jj,jk,jpn2s)= trn(ji,jj,jk,jpn2s)+denitr(ji,jj,jk)     &
      &      *rn_denn2o
           trn(ji,jj,jk,jpn2b)= trn(ji,jj,jk,jpn2b)+denitr(ji,jj,jk)     &
      &      *rn_degn2b
           trc3d(ji,jj,jk,21) = denitr(ji,jj,jk)*rn_degn2b*rfactr*1e3
           trn(ji,jj,jk,jpn2n)= trn(ji,jj,jk,jpn2n)+denitr(ji,jj,jk)     &
      &      *rn_degn2b
           denno3=max(-0.5,(rn_doxn2o-trno2(ji,jj,jk))     &
      &      /(2.*rn_doxn2o+trno2(ji,jj,jk)))
           denno3=(sin(denno3*rpi)+1.)/2.
           degn2o=min(trn(ji,jj,jk,jpn2o),                               &
      &      0.8*rato2c*consum*denno3*rn_degn2o)
           trn(ji,jj,jk,jpn2o)= trn(ji,jj,jk,jpn2o)-degn2o
           trc3d(ji,jj,jk,18) = degn2o*rfactr*1e3
           degn2o=min(trn(ji,jj,jk,jpn2s),                               &
      &      0.8*rato2c*consum*denno3*rn_degn2o)
           trn(ji,jj,jk,jpn2s)= trn(ji,jj,jk,jpn2s)-degn2o
           degn2o=min(trn(ji,jj,jk,jpn2b),                               &
      &      0.8*rato2c*consum*denno3*rn_degn2c)
           trn(ji,jj,jk,jpn2b)= trn(ji,jj,jk,jpn2b)-degn2o
           trc3d(ji,jj,jk,12) = degn2o*1e3*rfactr
           degn2o=min(trn(ji,jj,jk,jpn2n),                               &
      &      0.8*rato2c*consum*denno3*rn_degn2c)
           trn(ji,jj,jk,jpn2n)= trn(ji,jj,jk,jpn2n)-degn2o
!
! 0.5N2+2H2O -> NH4 +O2
!
            n2fix=(prophy(ji,jj,jk,jpfix,1)+docphy(ji,jj,jk,jpfix))*ratn2c* &
     &        (1.-dinpft(ji,jj,jk,jpfix))
!            trn(ji,jj,jk,jpoxy) = trn(ji,jj,jk,jpoxy)-delo2(ji,jj,jk)   &
!     &        +n2fix
!
            prodt = 0.
            proalk = 0.
!
! Evolution of phytoplankton
! --------------------------
!
!     Loop over phytoplankton types
!
            DO jl = jpdia, jpdia+jppft-1
!
              trn(ji,jj,jk,jppo4) = trn(ji,jj,jk,jppo4)                &
     &          -prophy(ji,jj,jk,jl,1)-docphy(ji,jj,jk,jl)
              trn(ji,jj,jk,jpno3) = trn(ji,jj,jk,jpno3)                 &
     &          -(prophy(ji,jj,jk,jl,1)+docphy(ji,jj,jk,jl))            &
     &          *ratn2c*dinpft(ji,jj,jk,jl)*pnophy(ji,jj,jk,jl)
              trn(ji,jj,jk,jpnh4) = trn(ji,jj,jk,jpnh4)                 &
     &          -(prophy(ji,jj,jk,jl,1)+docphy(ji,jj,jk,jl))            &
     &          *ratn2c*dinpft(ji,jj,jk,jl)*(1.-pnophy(ji,jj,jk,jl))
!
              prodt = prodt+prophy(ji,jj,jk,jl,1)  &
     &          +docphy(ji,jj,jk,jl)
              proalk = proalk+(prophy(ji,jj,jk,jl,1)+docphy(ji,jj,jk,jl))&
     &      *(alknut*pnophy(ji,jj,jk,jl)+rata2h*(1.-pnophy(ji,jj,jk,jl)))
!
! Loop over elements (C, Fe, Chl)
!
              DO jm = 0, 2
!
                trn(ji,jj,jk,jl+jm*jppft) = trn(ji,jj,jk,jl+jm*jppft)  &
     &            +prophy(ji,jj,jk,jl,jm+1)                            &
     &            -gramic(ji,jj,jk,jl,jm+1)                            &
     &            -grames(ji,jj,jk,jl,jm+1)                            &
     &            -gramac(ji,jj,jk,jl,jm+1)                            &
     &            -resphy(ji,jj,jk,jl,jm+1)
!
              END DO
!
              trn(ji,jj,jk,jpdoc) = trn(ji,jj,jk,jpdoc)+docphy(ji,jj,jk,jl)
!
!              trn(ji,jj,jk,jpoxy) = trn(ji,jj,jk,jpoxy)                &
!     &          +(rato2c+pnophy(ji,jj,jk,jl)*rato2n)                      &
!     &          *(prophy(ji,jj,jk,jl,1)+docphy(ji,jj,jk,jl))
!
              trn(ji,jj,jk,jpfer) = trn(ji,jj,jk,jpfer)                &
     &          -prophy(ji,jj,jk,jl,2)+resphy(ji,jj,jk,jl,2)
!
            END DO
!
! Evolution of Calcite
! --------------------
!
! Production of attached CaCO3 (no tracer, but subtracted from DIC and Alk)
!
            prcaca(ji,jj,jk) = rn_coccal*prophy(ji,jj,jk,jpcoc,1)
!
! Transfer of attached CaCO3 to sinking CaCO3 by loss processes.
!
            loscal = rn_coccal*(gramic(ji,jj,jk,jpcoc,1)               &
     &        +grames(ji,jj,jk,jpcoc,1)+resphy(ji,jj,jk,jpcoc,1)       &
     &        +gramac(ji,jj,jk,jpcoc,1))
!
            trn(ji,jj,jk,jpcal) = trn(ji,jj,jk,jpcal)+(1.-rn_discal)*loscal &
     &        +(sinkcal(ji,jj,jk)-sinkcal(ji,jj,jk+1))/fse3t(ji,jj,jk)
!
! Evolution of PO4
! ----------------
!
            trn(ji,jj,jk,jppo4) = trn(ji,jj,jk,jppo4)+consum           &
     &        +deppo4(ji,jj,jk)
!
            trn(ji,jj,jk,jpno3) = trn(ji,jj,jk,jpno3)-denitr(ji,jj,jk) &
     &        +depno3(ji,jj,jk)
            trn(ji,jj,jk,jpnh4) = trn(ji,jj,jk,jpnh4)+depnh4(ji,jj,jk)  &
     &        +consum*ratn2c
!
            prodt = prodt-consum
            proalk = proalk-consum*rata2h+denitr(ji,jj,jk)
!    
! Evolution of Protozooplankton
! -----------------------------
!     
            trn(ji,jj,jk,jpmic) = trn(ji,jj,jk,jpmic)-gramaz(ji,jj,jk) &
     &        -grazz(ji,jj,jk)-tormic(ji,jj,jk)-respz(ji,jj,jk)        &
     &        +micrge(ji,jj,jk)*gramit(ji,jj,jk)
!
! Evolution of Mesozooplankton
! ----------------------------
!
            trn(ji,jj,jk,jpmes) = trn(ji,jj,jk,jpmes)                  &
     &        +mesoge(ji,jj,jk)*gramet(ji,jj,jk)                       &
     &        -gramam(ji,jj,jk)-tormes(ji,jj,jk)-respz2(ji,jj,jk)
!
! Evolution of Macrozooplankton
! -----------------------------
!
            trn(ji,jj,jk,jpmac) = trn(ji,jj,jk,jpmac)                  &
     &        +macrge(ji,jj,jk)*gramat(ji,jj,jk)                       &
     &        -tormac(ji,jj,jk)-respz3(ji,jj,jk)
!
! Evolution of Bacteria
! ---------------------
!
            trn(ji,jj,jk,jpbac) = trn(ji,jj,jk,jpbac)+bactge(ji,jj,jk)*&
     &        (olimi(ji,jj,jk)+orem(ji,jj,jk)+orem2(ji,jj,jk))         &
     &        -resbac(ji,jj,jk)-morbac(ji,jj,jk)                       &
     &        -grabac(ji,jj,jk)-grazbac(ji,jj,jk)-grambac(ji,jj,jk)    
!    
! Evolution of DOC
! ----------------
!     
            trn(ji,jj,jk,jpdoc) = trn(ji,jj,jk,jpdoc)-olimi(ji,jj,jk)  &
     &        +morbac(ji,jj,jk)+resbac(ji,jj,jk)/3.0  &
     &        +grarem(ji,jj,jk)*(1.-rn_sigmic)                         &
     &        +grarem2(ji,jj,jk)*(1.-rn_sigmes)                        &
     &        +grarem3(ji,jj,jk)*(1.-rn_sigmac)                        &
     &        -xaggdoc(ji,jj,jk)-xaggdoc2(ji,jj,jk)+depdoc(ji,jj,jk)    
!
! Evolution of small POC
! ----------------------
!     
            trn(ji,jj,jk,jppoc) = trn(ji,jj,jk,jppoc)-orem(ji,jj,jk)   &
     &        +tormic(ji,jj,jk)+resbac(ji,jj,jk)/3.0  &
     &        +grapoc(ji,jj,jk)                                        &
     &        -grazm(ji,jj,jk)-grazpoc(ji,jj,jk)-grampoc(ji,jj,jk)     &
     &        +(sinking(ji,jj,jk)-sinking(ji,jj,jk+1))/fse3t(ji,jj,jk) &
     &        -xagg(ji,jj,jk)+xaggdoc(ji,jj,jk)+deppoc(ji,jj,jk)
!    
! Evolution of big POC
! --------------------
!
            trn(ji,jj,jk,jpgoc) = trn(ji,jj,jk,jpgoc)-orem2(ji,jj,jk)  &
     &        +tormes(ji,jj,jk)+tormac(ji,jj,jk)      &
     &        +grapoc2(ji,jj,jk)+grapoc3(ji,jj,jk)                     &
     &        -gramgoc(ji,jj,jk)-grazgoc(ji,jj,jk)-grazg(ji,jj,jk)     &
     &        +xagg(ji,jj,jk)+xaggdoc2(ji,jj,jk)                       &
     &        +(sinking2(ji,jj,jk)-sinking2(ji,jj,jk+1))/fse3t(ji,jj,jk)
!
! Evolution of dissolved Iron
! ---------------------------
!
            trn(ji,jj,jk,jpfer) = trn(ji,jj,jk,jpfer)                  &
     &        +ferat3*(respz3(ji,jj,jk)+respz2(ji,jj,jk)+respz(ji,jj,jk)&
     &        +morbac(ji,jj,jk))                                       &
     &        +grafer(ji,jj,jk)+grafer2(ji,jj,jk)+grafer3(ji,jj,jk)    &
     &        +ofer(ji,jj,jk)+ofer2(ji,jj,jk)                           &
     &        +rbafer(ji,jj,jk)-ubafer(ji,jj,jk)                       &
     &        -xscave(ji,jj,jk)+irondep(ji,jj,jk)+depfer(ji,jj,jk)       
!
! Evolution of small biogenic Iron
! --------------------------------
!
            trn(ji,jj,jk,jpsfe) = trn(ji,jj,jk,jpsfe)-grazpof(ji,jj,jk)&
     &        +rn_unamic*grmi2a(ji,jj,jk)-grazmf(ji,jj,jk)             &
     &        -grampof(ji,jj,jk)                                       &
     &        +ferat3*tormic(ji,jj,jk)-ofer(ji,jj,jk)                  &
     &        -xaggfe(ji,jj,jk)+scasfe(ji,jj,jk)                       &
     &        +(sinkfer(ji,jj,jk)-sinkfer(ji,jj,jk+1))/fse3t(ji,jj,jk) &
     &        +deppoc(ji,jj,jk)*ferat3
!
! Evolution of big biogenic Iron
! ------------------------------
!
            trn(ji,jj,jk,jpbfe) = trn(ji,jj,jk,jpbfe)                  &
     &        -grazgf(ji,jj,jk)                                        &
     &        +rn_unames*grme2a(ji,jj,jk)-grazgof(ji,jj,jk)            &
     &        +rn_unamac*grma2a(ji,jj,jk)-gramgof(ji,jj,jk)            &
     &        +ferat3*(tormes(ji,jj,jk)+tormac(ji,jj,jk))              &
     &        +xaggfe(ji,jj,jk)+scabfe(ji,jj,jk)-ofer2(ji,jj,jk)       &
     &        +(sinkfer2(ji,jj,jk)-sinkfer2(ji,jj,jk+1))/fse3t(ji,jj,jk)
!
! Evolution of biogenic Silica
! ----------------------------
!
            trn(ji,jj,jk,jpbsi) = trn(ji,jj,jk,jpbsi)                  &
     &        +prorca3(ji,jj,jk)-grazss(ji,jj,jk)                       &
     &        -resps(ji,jj,jk)-grazs(ji,jj,jk)-grasss(ji,jj,jk)
!
! Evolution of sinking biogenic silica
! ------------------------------------
!
            trn(ji,jj,jk,jpdsi)=trn(ji,jj,jk,jpdsi)                     &
     &        +resps(ji,jj,jk)+grazs(ji,jj,jk)-osil(ji,jj,jk)          &
     &        +grazss(ji,jj,jk)+grasss(ji,jj,jk)                       &
     &        +(sinksil(ji,jj,jk)-sinksil(ji,jj,jk+1))/fse3t(ji,jj,jk)
!
! Evolution of dissolved Silica
! -----------------------------
!
            trn(ji,jj,jk,jpsil) = trn(ji,jj,jk,jpsil)                  &
     &        -prorca3(ji,jj,jk)+osil(ji,jj,jk)                        &
     &        +depsil(ji,jj,jk)+sidep(ji,jj,jk)
!
! Evolution of DMS,DMD
! --------------------
!
!            trn(ji,jj,jk,jpdmd) = trn(ji,jj,jk,jpdmd)+                 &
!     &        prodmd(ji,jj,jk) - degdmd(ji,jj,jk)
!1
!            trn(ji,jj,jk,jpdms) = trn(ji,jj,jk,jpdms)+                 &
!     &        prodms(ji,jj,jk)+0.5*dmddms(ji,jj,jk)-degdms(ji,jj,jk)

!
! Consumption of Total (12C)O2
! ----------------------------
!     
            trn(ji,jj,jk,jpdic) = trn(ji,jj,jk,jpdic)                  &
     &        -prodt-prcaca(ji,jj,jk)+rn_discal*loscal       &
     &        +depdic(ji,jj,jk)
!     
! Consumption of alkalinity due to ca++ uptake and increase 
! of alkalinity due to nitrate consumption during organic 
! soft tissue production
! ------------------------------------------------------------------
!     
            trn(ji,jj,jk,jptal) = trn(ji,jj,jk,jptal)                  &
     &        +proalk-2.*prcaca(ji,jj,jk)+                              &
     &        2.*rn_discal*loscal+depdic(ji,jj,jk)
            trc3d(ji,jj,jk,15) = rn_nitnh4                              &
     &        *max((1.-log(trno2(ji,jj,jk)*1e6)*0.159)*(1.-denno3),0.)  &
!     &        *trn(ji,jj,jk,jpnh4)/(rn_lign2o+trn(ji,jj,jk,jpnh4))      &
     &        *tgfunc(ji,jj,jk,jpdia+jppft)
            nitrif = trc3d(ji,jj,jk,15)*rfact/rjjss*trn(ji,jj,jk,jpnh4)
            trn(ji,jj,jk,jpno3)=trn(ji,jj,jk,jpno3)+nitrif
            trn(ji,jj,jk,jpnh4)=trn(ji,jj,jk,jpnh4)-nitrif
!            trn(ji,jj,jk,jpoxy)=trn(ji,jj,jk,jpoxy)-rato2n*nitrif
            trn(ji,jj,jk,jptal)=trn(ji,jj,jk,jptal)-2.*nitrif
            deln2o = nitrif*rn_aoun2o
            trn(ji,jj,jk,jpn2o)= trn(ji,jj,jk,jpn2o)+deln2o
            trc3d(ji,jj,jk,16) = deln2o*rfactr*1e3
            deln2o = nitrif*rn_aoun2s
            trn(ji,jj,jk,jpn2s)= trn(ji,jj,jk,jpn2s)+deln2o
            trc3d(ji,jj,jk,19) = deln2o*rfactr*1e3
            deln2o = nitrif*rn_denn2b
            trn(ji,jj,jk,jpn2b)= trn(ji,jj,jk,jpn2b)+deln2o
            trc3d(ji,jj,jk,20) = deln2o*rfactr*1e3
            deln2o = nitrif*rn_atmn2o
            trn(ji,jj,jk,jpn2n)= trn(ji,jj,jk,jpn2n)+deln2o
            trc3d(ji,jj,jk,22) = deln2o*rfactr*1e3
#    if defined key_trc_diaadd
!
! Save additional diagnostics
!
            trc3d(ji,jj,jk,1) = (sinking2(ji,jj,jk)+sinking(ji,jj,jk))*1e3*rfactr
            trc3d(ji,jj,jk,4) = 0.
            trc3d(ji,jj,jk,5) = 0.
            trc3d(ji,jj,jk,6) = 0.
            trc3d(ji,jj,jk,8) = 0.
            trc3d(ji,jj,jk,23) = 0.
            trc3d(ji,jj,jk,24) = 0.
            trc2d(ji,jj,17) = trc2d(ji,jj,17)+grazz(ji,jj,jk)*rfactr*1e3*fse3t(ji,jj,jk)
            trc2d(ji,jj,26) = trc2d(ji,jj,26)+(gramam(ji,jj,jk)+gramaz(ji,jj,jk))*rfactr*1e3*fse3t(ji,jj,jk)
!
            DO jl = jpdia, jpdia+jppft-1
              trc3d(ji,jj,jk,4) = trc3d(ji,jj,jk,4)+prophy(ji,jj,jk,jl,1)*rfactr*1e3
              trc3d(ji,jj,jk,5) = trc3d(ji,jj,jk,5)+gramic(ji,jj,jk,jl,1)*rfactr*1e3
              trc3d(ji,jj,jk,6) = trc3d(ji,jj,jk,6)+grames(ji,jj,jk,jl,1)*rfactr*1e3
              trc3d(ji,jj,jk,8) = trc3d(ji,jj,jk,8)+gramac(ji,jj,jk,jl,1)*rfactr*1e3
              trc3d(ji,jj,jk,23) = trc3d(ji,jj,jk,23)+docphy(ji,jj,jk,jl)*rfactr*1e3
              trc3d(ji,jj,jk,24) = trc3d(ji,jj,jk,24)+(prophy(ji,jj,jk,jl,1)+docphy(ji,jj,jk,jl)) &
     &          *dinpft(ji,jj,jk,jl)*(1.-pnophy(ji,jj,jk,jl))*rfactr*1e3
            END DO
            trc3d(ji,jj,jk,9) = denitr(ji,jj,jk)*rfactr*1e3
            trc3d(ji,jj,jk,10) = delo2(ji,jj,jk)*1e3*rfactr
            trc3d(ji,jj,jk,11) = (prophy(ji,jj,jk,jpfix,1)              &
     &        +docphy(ji,jj,jk,jpfix))*ratn2c*(1.-dinpft(ji,jj,jk,jpfix))&
     &        *rfactr*1.e3
#    endif
          END DO
        END DO
      END DO
      DO jk = nn_deun2s, jpk-1
        DO jj = 2, nlcj-1
          DO ji = 2, nlci-1
            dumn2o = delo2(ji,jj,jk)
            duon2o = dumn2o                                             &
     &        *exp(rn_decn2s*(trno2(ji,jj,jk)-rn_omxn2s)/rn_omxn2s)
            trn(ji,jj,jk,jpn2a)= trn(ji,jj,jk,jpn2a)+dumn2o*rn_denn2a   &
     &        +duon2o*rn_degn2a
            trc3d(ji,jj,jk,2) = dumn2o*rn_denn2a*1e3*rfactr
            trc3d(ji,jj,jk,3) = duon2o*rn_degn2a*1e3*rfactr
            trn(ji,jj,jk,jpn2c)= trn(ji,jj,jk,jpn2c)+dumn2o*rn_denn2c   &
     &        +duon2o*rn_degn2a
            trc3d(ji,jj,jk,14) = dumn2o*rn_denn2c*1e3*rfactr
            trn(ji,jj,jk,jpn2d)= trn(ji,jj,jk,jpn2d)+dumn2o*rn_denn2d   &
     &        +duon2o*rn_degn2d
            trc3d(ji,jj,jk,9) = dumn2o*rn_denn2d*1e3*rfactr
            trc3d(ji,jj,jk,13) = duon2o*rn_degn2d*1e3*rfactr
            trn(ji,jj,jk,jpn2e)= trn(ji,jj,jk,jpn2e)+dumn2o*rn_denn2e   &
     &        +duon2o*rn_degn2d
            trc3d(ji,jj,jk,7) = dumn2o*rn_denn2e*1e3*rfactr
          END DO
        END DO
      END DO
#    if defined key_trc_diaadd
      DO jj = 2, nlcj-1
        DO ji = 2, nlci-1
!MICRO
          trc2d(ji,jj,3) = depno3(ji,jj,1)*rfactr*1e3
          trc2d(ji,jj,4) = depnh4(ji,jj,1)*rfactr*1e3
          trc2d(ji,jj,5) = depnit(ji,jj,1)*1e3*rfactr
          trc2d(ji,jj,7) = grabac(ji,jj,1)*rfactr*1e3
          trc2d(ji,jj,8) = grabac(ji,jj,1)*rfactr*1e3
!MESO
          trc2d(ji,jj,9) = respz2(ji,jj,1)*rfactr*1e3
          trc2d(ji,jj,10) = tormes(ji,jj,1)*rfactr*1e3
!MACRO
          ik=nmlb(ji,jj)
          trc2d(ji,jj,18) = trn(ji,jj,ik,jpdch)+trn(ji,jj,ik,jpnch)+trn(ji,jj,ik,jpcch)+&
     &                      trn(ji,jj,ik,jppch)+trn(ji,jj,ik,jphch)+trn(ji,jj,ik,jpfch)
!PHYTO
          trc2d(ji,jj,2) = zmeu(ji,jj)
          trc2d(ji,jj,29) = hmlb(ji,jj)
          trc2d(ji,jj,16) = trn(ji,jj,1,jpdch)+trn(ji,jj,1,jpnch)+trn(ji,jj,1,jpcch)+&
     &                      trn(ji,jj,1,jppch)+trn(ji,jj,1,jphch)+trn(ji,jj,1,jpfch)
        END DO
      END DO

#    endif
#endif
      RETURN
      END
