      SUBROUTINE bgclos
#if defined key_top
!CC   ------------------------------------------------------------------
!CC   
!CC   ROUTINE bgclos: DGOM MODEL
!CC   ****************************
!CC   
!C
!C     PURPOSE.
!C     --------
!C                   Calculates loss terms of all plankton
!C     EXTERNALS.
!C     ----------
!C          NONE.
!C
!C   MODIFICATIONS:
!C   --------------
!C      original p4zloss : 2002    E. Buitenhuis
!C ---------------------------------------------------------------------
      USE trp_trc
      USE sms
      USE oce_trc
      IMPLICIT NONE
!
! local variables
!
      INTEGER ji, jj, jk, jl
      REAL compabac(jpi,jpj,jpk)
      REAL compapoc(jpi,jpj,jpk),compagoc(jpi,jpj,jpk)
      REAL compamic(jpi,jpj,jpk),compames(jpi,jpj,jpk),compamac(jpi,jpj,jpk)
      REAL compabio(jpi,jpj,jpk)
      REAL dyphy(jpi,jpj,jpk)
      REAL graze(jpi,jpj,jpk),graze2(jpi,jpj,jpk),graze3(jpi,jpj,jpk)
      REAL xdenom(jpi,jpj,jpk),ydenom(jpi,jpj,jpk),zdenom(jpi,jpj,jpk)
      REAL zmormic,zpromic,zmormes,zpromes,zmormac,zpromac
      REAL zmornmi,zmornme,zmornma
      REAL ztpmic,ztpmes,ztpmac
      REAL zmokmes,zmokmac
      REAL zgramin,zgramax
!
! local dgom variables
!
      REAL compap(jpi,jpj,jpk,jpdia:jpdia+jppft-1),tstdia(jpi,jpj,jpk)
      REAL zlosphy(jpi,jpj,jpk,jpdia:jpdia+jppft-1)
      REAL grma2a(jpi,jpj,jpk)
      REAL grme2a(jpi,jpj,jpk)
      REAL grmi2a(jpi,jpj,jpk)

      REAL zgrdmp,zstre1(jpi,jpj,jpk),zstre2,zstre3
!
      dmspp = 0.
      prodmd = 0.
      prodms = 0.
! 
!     Compute the sum of the preferences
!
      ztpmic = rn_gmibac + rn_gmipoc + rn_gmigoc 
      ztpmes = rn_gmebac + rn_gmepoc + rn_gmegoc + rn_gmemic
      ztpmac = rn_gmapoc + rn_gmagoc + rn_gmames + rn_gmamic + rn_gmabac 
!   
      DO jl = jpdia, jpdia+jppft-1
        ztpmic = ztpmic + rn_gmiphy(jl)
        ztpmes = ztpmes + rn_gmephy(jl)
        ztpmac = ztpmac + rn_gmaphy(jl)
      ENDDO
! 
      zmornmi = 0.
      zmornme = 0.
      zmornma = 0.
!
! -------------------------------------------------------------------
! Big loop to compute the various sink and source terms 
! for phytoplankton, zooplankton and organic matter reservoirs. 
! -------------------------------------------------------------------
!     
! no grazing if concentration goes below zgramin (Strom et al., MEPS 2000)
!
      zgramin = 5.e-8
!
! no grazing if concentration goes above zgramax (not activated)
!
!     zgramax = 5.e-7
!
      DO jk = 1, jpk-1
        DO jj = 2, nlcj-1
          DO ji = 2, nlci-1
!     
            zmormic = 0.
            zmormes = 0.
            zmormac = 0.
!
! Protect plankton from extinction
!     
            compabac(ji,jj,jk) = max((trn(ji,jj,jk,jpbac)-zgramin),0.)
            compamic(ji,jj,jk) = max((trn(ji,jj,jk,jpmic)-zgramin),0.)
            compames(ji,jj,jk) = max((trn(ji,jj,jk,jpmes)-zgramin),0.)
            compamac(ji,jj,jk) = max((trn(ji,jj,jk,jpmac)-zgramin),0.)
            compagoc(ji,jj,jk) = max((trn(ji,jj,jk,jpgoc)-zgramin),0.)
            compapoc(ji,jj,jk) = max((trn(ji,jj,jk,jppoc)-zgramin),0.)
!
! sum all the phyto + zoo biomass 
!
            compabio(ji,jj,jk)=0. 
            DO jl = jpmic, jpdia+jppft-1
              compabio(ji,jj,jk) = compabio(ji,jj,jk) + trn(ji,jj,jk,jl)
            ENDDO
!
! k-half for top mortality
!
            zmokmes = 20.e-6
            zmokmac = 20.e-6
!
! -------------------------------------------------------------------
! Respiration and mortality rates of phytoplankton as a fraction of growth
! -------------------------------------------------------------------
!
! respiration
!
            DO jl = jpdia, jpdia+jppft-1
              zlosphy(ji,jj,jk,jl) = rn_resphy(jl)*rn_mumpft(jl)*tgfunc(ji,jj,jk,jl)
              compap(ji,jj,jk,jl) = max((trn(ji,jj,jk,jl)-zgramin),0.)
!
              resphy(ji,jj,jk,jl,1) = zlosphy(ji,jj,jk,jl)*compap(ji,jj,jk,jl) &
     &          /rjjss*rfact*tmask(ji,jj,jk)
              resphy(ji,jj,jk,jl,2) = resphy(ji,jj,jk,jl,1)      &
     &           *trn(ji,jj,jk,jl+jppft)/(trn(ji,jj,jk,jl)+rtrn)
              resphy(ji,jj,jk,jl,3) = resphy(ji,jj,jk,jl,1)      &
     &           *trn(ji,jj,jk,jl+2*jppft)/(trn(ji,jj,jk,jl)+rtrn)
            END DO
!
! -------------------------------------------------------------------
! Respiration rates of zooplankton
! -------------------------------------------------------------------
!
! microzooplankton 
!
         respz(ji,jj,jk) = rn_resmic*rn_retmic**tn(ji,jj,jk) &
     &     /rjjss*rfact*compamic(ji,jj,jk)*tmask(ji,jj,jk)
!
! mesozooplankton 
!
         respz2(ji,jj,jk) = rn_resmes*(rn_retmes**tn(ji,jj,jk)) &
     &     /rjjss*rfact*compames(ji,jj,jk)*tmask(ji,jj,jk)
!
! macrozooplankton 
!
         respz3(ji,jj,jk) = rn_resmac*(rn_retmac**tn(ji,jj,jk)) &
     &     /rjjss*rfact*compamac(ji,jj,jk)*tmask(ji,jj,jk)
!
! -------------------------------------------------------------------
! Grazing rates of zooplankton as a function of temperature
! -------------------------------------------------------------------
!
! microzooplankton 
!
         graze(ji,jj,jk) = rn_gramic/rjjss*rfact*tmask(ji,jj,jk)*tgfunc(ji,jj,jk,jpmic)
!
! mesozooplankton 
!
         graze2(ji,jj,jk) = rn_grames/rjjss*rfact*tmask(ji,jj,jk)*tgfunc(ji,jj,jk,jpmes)
!
! macrozooplankton
!
         graze3(ji,jj,jk) = rn_gramac/rjjss*rfact*tmask(ji,jj,jk)*tgfunc(ji,jj,jk,jpmac) 
!
! compute denominator
!
          zdenom(ji,jj,jk) = rn_grkmic-rn_grmmic+                       &
     &      rn_gmibac*trn(ji,jj,jk,jpbac)+                              &
     &      rn_gmipoc*trn(ji,jj,jk,jppoc)+                              &
     &      rn_gmigoc*trn(ji,jj,jk,jpgoc)
          xdenom(ji,jj,jk) = rn_grkmes-rn_grmmes+                       &
     &      rn_gmebac*trn(ji,jj,jk,jpbac)+                              &
     &      rn_gmepoc*trn(ji,jj,jk,jppoc)+                              &
     &      rn_gmegoc*trn(ji,jj,jk,jpgoc)+                              &
     &      rn_gmemic*trn(ji,jj,jk,jpmic)
          ydenom(ji,jj,jk) = rn_grkmac-rn_grmmac+                       &
     &      rn_gmabac*trn(ji,jj,jk,jpbac)+                              &
     &      rn_gmapoc*trn(ji,jj,jk,jppoc)+                              &
     &      rn_gmagoc*trn(ji,jj,jk,jpgoc)+                              &
     &      rn_gmamic*trn(ji,jj,jk,jpmic)+                              &
     &      rn_gmames*trn(ji,jj,jk,jpmes)
!
          DO jl = jpdia, jpdia+jppft-1
!
            zdenom(ji,jj,jk) = zdenom(ji,jj,jk)+rn_gmiphy(jl)*compap(ji,jj,jk,jl)
            xdenom(ji,jj,jk) = xdenom(ji,jj,jk)+rn_gmephy(jl)*trn(ji,jj,jk,jl)
            ydenom(ji,jj,jk) = ydenom(ji,jj,jk)+rn_gmaphy(jl)*trn(ji,jj,jk,jl)
!
          END DO
!
          resps(ji,jj,jk) = resphy(ji,jj,jk,jpdia,1)                       &
     &          *trn(ji,jj,jk,jpbsi)/(trn(ji,jj,jk,jpdia)+rtrn)
!     
! -------------------------------------------------------------------
! Zooplankton mortality
! -------------------------------------------------------------------
!
! coastal mortality
!
          tormic(ji,jj,jk) = 0.
          tormes(ji,jj,jk) = 0.
          tormac(ji,jj,jk) = 0.
!
          tormic(ji,jj,jk) = rn_coazoo*rcoast(ji,jj)*rn_gramic/rjjss*rfact* &
     &           compamic(ji,jj,jk)*tmask(ji,jj,jk)*tgfunc(ji,jj,jk,jpmic)
!
          tormes(ji,jj,jk) = rn_coazoo*rcoast(ji,jj)*rn_grames/rjjss*rfact* &
     &           compames(ji,jj,jk)*tmask(ji,jj,jk)*tgfunc(ji,jj,jk,jpmes)
!
          tormac(ji,jj,jk) = rn_coazoo*rcoast(ji,jj)*rn_gramac/rjjss*rfact* &
     &           compamac(ji,jj,jk)*tmask(ji,jj,jk)*tgfunc(ji,jj,jk,jpmac)
!     
! add mortality by top predators on mesozoo, using global biomass as a proxy 
!
          tormes(ji,jj,jk) = tormes(ji,jj,jk) +                           &
     &       rn_mormes/rjjss*rfact*compames(ji,jj,jk)/(zmokmes+compames(ji,jj,jk))*compabio(ji,jj,jk) &
     &       *tmask(ji,jj,jk)*(rn_motmes**tn(ji,jj,jk))
!
! add mortality by top predators on macrozoo, using global biomass as a proxy 
!
          tormac(ji,jj,jk) = tormac(ji,jj,jk) +                           &
     &       rn_mormac/rjjss*rfact*compamac(ji,jj,jk)/(zmokmac+compamac(ji,jj,jk))*compabio(ji,jj,jk) &
     &       *tmask(ji,jj,jk)*(rn_motmac**tn(ji,jj,jk))
!
! macrozooplankton predation mortality turns to near zero when ice is present. 
!     this is a protection mechanisms specific to krill. 
!
          tormac(ji,jj,jk) = tormac(ji,jj,jk) *                           &
     &       max( (1.- fr_i(ji,jj)/(fr_i(ji,jj)+rtrn)) ,0.01)
!     
! -------------------------------------------------------------------
! Preference of zooplankton for Phyto and POC (Fasham et al. 1990)
! -------------------------------------------------------------------
!
! ----------------------------
! grazing on non-phytoplankton
! ----------------------------
!
! microzoo grazing
!
          zpromic=graze(ji,jj,jk)*trn(ji,jj,jk,jpmic)/zdenom(ji,jj,jk)
!
!    grazing on poc
!
          grazm(ji,jj,jk) = zpromic*(rn_gmipoc*compapoc(ji,jj,jk)-        &
     &                              rn_gmipoc/ztpmic*rn_grmmic)
          zmornmi = min(grazm(ji,jj,jk),0.)
          zmormic = zmormic + zmornmi 
          grazm(ji,jj,jk) = max(grazm(ji,jj,jk),0.)
!
!    grazing on mic
!
          grazg(ji,jj,jk) = zpromic*(rn_gmigoc*compagoc(ji,jj,jk)-        &
     &                              rn_gmigoc/ztpmic*rn_grmmic)
          zmornmi = min(grazg(ji,jj,jk),0.)
          zmormic = zmormic + zmornmi
          grazg(ji,jj,jk) = max(grazg(ji,jj,jk),0.)
!
!    grazing on bac
!
          grabac(ji,jj,jk) = zpromic*(rn_gmibac*compabac(ji,jj,jk)-       &
     &                               rn_gmibac/ztpmic*rn_grmmic)
          zmornmi = min(grabac(ji,jj,jk),0.)
          zmormic = zmormic + zmornmi
          grabac(ji,jj,jk) = max(grabac(ji,jj,jk),0.)
!
! mesozoo grazing
!
          zpromes=graze2(ji,jj,jk)*trn(ji,jj,jk,jpmes)/xdenom(ji,jj,jk)
!
!    grazing on mic
!
          grazz(ji,jj,jk) = zpromes*(rn_gmemic*compamic(ji,jj,jk)-        &
     &                              rn_gmemic/ztpmes*rn_grmmes)
          zmornme = min(grazz(ji,jj,jk),0.)
          zmormes = zmormes + zmornme
          grazz(ji,jj,jk) = max(grazz(ji,jj,jk),0.)
!
!    grazing on poc
!
          grazpoc(ji,jj,jk) = zpromes*(rn_gmepoc*compapoc(ji,jj,jk)-      &
     &                                rn_gmepoc/ztpmes*rn_grmmes)
          zmornme = min(grazpoc(ji,jj,jk),0.)
          zmormes = zmormes + zmornme
          grazpoc(ji,jj,jk) = max(grazpoc(ji,jj,jk),0.)
!
!    grazing on goc
!
          grazgoc(ji,jj,jk) = zpromes*(rn_gmegoc*compagoc(ji,jj,jk)-      &
     &                                rn_gmegoc/ztpmes*rn_grmmes)
          zmornme = min(grazgoc(ji,jj,jk),0.)
          zmormes = zmormes + zmornme
          grazgoc(ji,jj,jk) = max(grazgoc(ji,jj,jk),0.)
!
!    grazing on bac
!
          grazbac(ji,jj,jk) = zpromes*(rn_gmebac*                         &
     &          compabac(ji,jj,jk) - rn_gmebac/ztpmes*rn_grmmes)
          zmornme = min(grazbac(ji,jj,jk),0.)
          zmormes = zmormes + zmornme
          grazbac(ji,jj,jk) = max(grazbac(ji,jj,jk),0.)
!
! macrozoo grazing
!
          zpromac=graze3(ji,jj,jk)*trn(ji,jj,jk,jpmac)/ydenom(ji,jj,jk)
!
!    grazing on mes
!
          gramam(ji,jj,jk) = zpromac*(rn_gmames*                          &
     &          compames(ji,jj,jk) - rn_gmames/ztpmac*rn_grmmac)
          zmornma = min(gramam(ji,jj,jk),0.)
          zmormac = zmormac + zmornma
          gramam(ji,jj,jk) = max(gramam(ji,jj,jk),0.)
!
!    grazing on mic
!
          gramaz(ji,jj,jk) = zpromac*(rn_gmamic*                          &
     &          compamic(ji,jj,jk) - rn_gmamic/ztpmac*rn_grmmac)
          zmornma = min(gramaz(ji,jj,jk),0.)
          zmormac = zmormac + zmornma
          gramaz(ji,jj,jk) = max(gramaz(ji,jj,jk),0.)
!
!    grazing on bac
!
          grambac(ji,jj,jk) = zpromac*(rn_gmabac*                         &
     &          compabac(ji,jj,jk) - rn_gmabac/ztpmac*rn_grmmac)
          zmornma = min(grambac(ji,jj,jk),0.)
          zmormac = zmormac + zmornma
          grambac(ji,jj,jk) = max(grambac(ji,jj,jk),0.)
!
!    grazing on poc
!
          grampoc(ji,jj,jk) = zpromac*(rn_gmapoc*                         &
     &          compapoc(ji,jj,jk) - rn_gmapoc/ztpmac*rn_grmmac)
          zmornma = min(grampoc(ji,jj,jk),0.)
          zmormac = zmormac + zmornma
          grampoc(ji,jj,jk) = max(grampoc(ji,jj,jk),0.)
!
!    grazing on goc
!
          gramgoc(ji,jj,jk) = zpromac*(rn_gmagoc*                         &
     &          compagoc(ji,jj,jk) - rn_gmagoc/ztpmac*rn_grmmac)
          zmornma = min(gramgoc(ji,jj,jk),0.)
          zmormac = zmormac + zmornma
          gramgoc(ji,jj,jk) = max(gramgoc(ji,jj,jk),0.)
!
          grampof(ji,jj,jk) = grampoc(ji,jj,jk)*                          &
     &          trn(ji,jj,jk,jpsfe)/(trn(ji,jj,jk,jppoc)+rtrn)
          gramgof(ji,jj,jk) = gramgoc(ji,jj,jk)*                          &
     &          trn(ji,jj,jk,jpbfe)/(trn(ji,jj,jk,jpgoc)+rtrn)
!
          gramit(ji,jj,jk) = 0.
          grmi2a(ji,jj,jk) = 0.

          gramet(ji,jj,jk) = 0.
          grme2a(ji,jj,jk) = 0.

          gramat(ji,jj,jk) = gramam(ji,jj,jk)+gramaz(ji,jj,jk)            &
     &      +grampoc(ji,jj,jk)+gramgoc(ji,jj,jk)
          grma2a(ji,jj,jk) = (gramam(ji,jj,jk)+gramaz(ji,jj,jk))*ferat3   &
     &      +grampof(ji,jj,jk)+gramgof(ji,jj,jk)
!
          grapoc(ji,jj,jk)=0.
!
! ------------------------
! grazing on phytoplankton
! ------------------------
!
          DO jl = jpdia, jpdia+jppft-1
!
            tstdia(ji,jj,jk)=0.5005+sign(0.4995,DBLE(jpdia-jl))
!
! microzoo grazing
!
            gramic(ji,jj,jk,jl,1) = zpromic*(rn_gmiphy(jl)                &
     &           *compap(ji,jj,jk,jl)- rn_gmiphy(jl)/ztpmic*rn_grmmic)
!
            zmornmi = min(gramic(ji,jj,jk,jl,1),0.)
            zmormic = zmormic + zmornmi
!
            gramic(ji,jj,jk,jl,1) = max(gramic(ji,jj,jk,jl,1),0.)
            gramic(ji,jj,jk,jl,2) =  gramic(ji,jj,jk,jl,1)*               &
     &           trn(ji,jj,jk,jl+jppft)/(trn(ji,jj,jk,jl)+rtrn)
            gramic(ji,jj,jk,jl,3) =  gramic(ji,jj,jk,jl,1)*               &
     &           trn(ji,jj,jk,jl+2*jppft)/(trn(ji,jj,jk,jl)+rtrn)
            gramit(ji,jj,jk)=gramit(ji,jj,jk)+gramic(ji,jj,jk,jl,1)
            grmi2a(ji,jj,jk)=grmi2a(ji,jj,jk)+gramic(ji,jj,jk,jl,2)
!
! mesozoo grazing
!
            grames(ji,jj,jk,jl,1) = zpromes*(rn_gmephy(jl)                &
     &           *compap(ji,jj,jk,jl)-rn_gmephy(jl)/ztpmes*rn_grmmes)
            zmornme = min(grames(ji,jj,jk,jl,1),0.)
            zmormes = zmormes + zmornme
            grames(ji,jj,jk,jl,1) = max(grames(ji,jj,jk,jl,1),0.)
!
            grames(ji,jj,jk,jl,2) =  grames(ji,jj,jk,jl,1)*               &
     &           trn(ji,jj,jk,jl+jppft)/(trn(ji,jj,jk,jl)+rtrn)
            grames(ji,jj,jk,jl,3) =  grames(ji,jj,jk,jl,1)*               &
     &           trn(ji,jj,jk,jl+2*jppft)/(trn(ji,jj,jk,jl)+rtrn)
            gramet(ji,jj,jk)=gramet(ji,jj,jk)+grames(ji,jj,jk,jl,1)
            grme2a(ji,jj,jk)=grme2a(ji,jj,jk)+grames(ji,jj,jk,jl,2)
!
! macrozoo grazing
!
            gramac(ji,jj,jk,jl,1) = zpromac*(rn_gmaphy(jl)*               &
     &           compap(ji,jj,jk,jl)-rn_gmaphy(jl)/ztpmac*rn_grmmac)
            zmornma = min(gramac(ji,jj,jk,jl,1),0.)
            zmormac = zmormac + zmornma
            gramac(ji,jj,jk,jl,1) = max(gramac(ji,jj,jk,jl,1),0.)
!
            gramac(ji,jj,jk,jl,2) = gramac(ji,jj,jk,jl,1)*                &
     &           trn(ji,jj,jk,jl+jppft)/(trn(ji,jj,jk,jl)+rtrn)
            gramac(ji,jj,jk,jl,3) = gramac(ji,jj,jk,jl,1)*                &
     &           trn(ji,jj,jk,jl+2*jppft)/(trn(ji,jj,jk,jl)+rtrn)
            gramat(ji,jj,jk)=gramat(ji,jj,jk)+gramac(ji,jj,jk,jl,1)
            grma2a(ji,jj,jk)=grma2a(ji,jj,jk)+gramac(ji,jj,jk,jl,2)
          END DO
!
          tormic(ji,jj,jk) = -1.*zmormic + tormic(ji,jj,jk)
!
          grazmf(ji,jj,jk) = grazm(ji,jj,jk)*trn(ji,jj,jk,jpsfe)/(trn(ji,jj,jk,jppoc)+rtrn)
          grazgf(ji,jj,jk) = grazg(ji,jj,jk)*trn(ji,jj,jk,jpbfe)/(trn(ji,jj,jk,jpgoc)+rtrn)
          gramit(ji,jj,jk) = gramit(ji,jj,jk)+grazg(ji,jj,jk)+grazm(ji,jj,jk)
          grmi2a(ji,jj,jk) = grmi2a(ji,jj,jk)+grazgf(ji,jj,jk)+grazmf(ji,jj,jk)

!
! add the starving mortality with external mortality by higher predators
!
          tormes(ji,jj,jk) = -1.*zmormes + tormes(ji,jj,jk)
          tormac(ji,jj,jk) = -1.*zmormac + tormac(ji,jj,jk)
!
          grazpof(ji,jj,jk) = grazpoc(ji,jj,jk)*                          &
     &          trn(ji,jj,jk,jpsfe)/(trn(ji,jj,jk,jppoc)+rtrn)
!
          grazgof(ji,jj,jk) = grazgoc(ji,jj,jk)*                          &
     &          trn(ji,jj,jk,jpbfe)/(trn(ji,jj,jk,jpgoc)+rtrn)
          gramet(ji,jj,jk) = gramet(ji,jj,jk)+grazz(ji,jj,jk)             &
     &      +grazpoc(ji,jj,jk)+grazgoc(ji,jj,jk)
          grme2a(ji,jj,jk) = grme2a(ji,jj,jk)+grazz(ji,jj,jk)*ferat3      &
     &      +grazpof(ji,jj,jk)+grazgof(ji,jj,jk)
!
! zooplankton model growth efficiency
!      if meso food respiration is lower than basal respiration increase GE
!      if there's not enough iron in food, decrease GE
!
          mesoge(ji,jj,jk)=min(1.-rn_unames,                              &
     &      rn_ggemes+respz2(ji,jj,jk)/max(rtrn,gramet(ji,jj,jk)),        &
     &      grme2a(ji,jj,jk)*(1.-rn_unames)/max(gramet(ji,jj,jk)*ferat3,minfer))

          micrge(ji,jj,jk)=min(1.-rn_unamic,                              &
     &      rn_ggemic+tn(ji,jj,jk)*rn_ggtmic+respz(ji,jj,jk)/max(rtrn,gramit(ji,jj,jk)),         &
     &      grmi2a(ji,jj,jk)*(1.-rn_unamic)/max(gramit(ji,jj,jk)*ferat3,minfer))
          macrge(ji,jj,jk)=min(1.-rn_unamac,                              &
     &      rn_ggemac+respz3(ji,jj,jk)/max(rtrn,gramat(ji,jj,jk)),        &
     &      grma2a(ji,jj,jk)*(1.-rn_unamac)/max(gramat(ji,jj,jk)*ferat3,minfer))
!
! grazing on diatom Si
!
          grazss(ji,jj,jk) = gramic(ji,jj,jk,jpdia,1)*                    &
     &           trn(ji,jj,jk,jpbsi)/(trn(ji,jj,jk,jpdia)+rtrn)
          grazs(ji,jj,jk) = grames(ji,jj,jk,jpdia,1)*                     &
     &          trn(ji,jj,jk,jpbsi)/(trn(ji,jj,jk,jpdia)+rtrn)
          grasss(ji,jj,jk) = gramac(ji,jj,jk,jpdia,1)*                    &
     &          trn(ji,jj,jk,jpbsi)/(trn(ji,jj,jk,jpdia)+rtrn)
!
! sum of grazing
!
          grarem(ji,jj,jk)=gramit(ji,jj,jk)*(1.-micrge(ji,jj,jk)-rn_unamic)
          grapoc(ji,jj,jk)=grapoc(ji,jj,jk)+gramit(ji,jj,jk)*rn_unamic
          grarem2(ji,jj,jk)=gramet(ji,jj,jk)*(1.-mesoge(ji,jj,jk)-rn_unames)
          grafer(ji,jj,jk)=grmi2a(ji,jj,jk)                               &
     &      *(1.-rn_unamic)-ferat3*micrge(ji,jj,jk)*gramit(ji,jj,jk)

          grafer2(ji,jj,jk)=grme2a(ji,jj,jk)                              &
     &      *(1.-rn_unames)-ferat3*mesoge(ji,jj,jk)*gramet(ji,jj,jk)

          grapoc2(ji,jj,jk)=gramet(ji,jj,jk)*rn_unames
          grarem3(ji,jj,jk)=gramat(ji,jj,jk)*(1.-macrge(ji,jj,jk)-rn_unamac)
          grafer3(ji,jj,jk)=grma2a(ji,jj,jk)                              &
     &      *(1.-rn_unamac)-ferat3*macrge(ji,jj,jk)*gramat(ji,jj,jk)
          grapoc3(ji,jj,jk)=gramat(ji,jj,jk)*rn_unamac

!
! -------------------------------------------------------------------
! DMS cycle - production terms for DMS(Pd)
! -------------------------------------------------------------------
!
          zstre1(ji,jj,jk) = max(etot(ji,jj,jk)/rn_etomax , 0.3)
!
	  DO jl = jpdia, jpdia+jppft-1

            zstre2 = rn_kmfphy(jl)/(trn(ji,jj,jk,jpfer)+ rn_kmfphy(jl))
!
! N stress
!
            zstre3 = rn_kmnphy(jl)/(trn(ji,jj,jk,jpno3)+rn_kmnphy(jl))
            rphdmd(ji,jj,jk,jl) = (min(max(zstre1(ji,jj,jk), zstre2,      &
     &              zstre3,0.3),1.)-0.00)*rn_rphdmd(jl)
! 
            zgrdmp = gramic(ji,jj,jk,jl,1)*(1.-micrge(ji,jj,jk))+         &
     &               grames(ji,jj,jk,jl,1)*(1.-mesoge(ji,jj,jk)-rn_assdms(1)*rn_unames)+ &
     &               gramac(ji,jj,jk,jl,1)*(1.-macrge(ji,jj,jk)-rn_assdms(2)*rn_unamac)

            prodmd(ji,jj,jk) = prodmd(ji,jj,jk)+((1.-rn_rdddms)*          &
     &               zgrdmp)*rphdmd(ji,jj,jk,jl)

            prodms(ji,jj,jk) = prodms(ji,jj,jk)+(rn_rdddms*zgrdmp+        &
     &               rn_xpldmd(jl)*rfact/rjjss*etot(ji,jj,jk)/rn_etomax*  &
     &               trn(ji,jj,jk,jl))*rphdmd(ji,jj,jk,jl)
            dmspp(ji,jj,jk) = dmspp(ji,jj,jk)+rphdmd(ji,jj,jk,jl)*        &
     &               trn(ji,jj,jk,jl)
!
          END DO
!
!
          END DO
        END DO
      END DO
#endif
      RETURN
      END
