      SUBROUTINE bgcnul
#if defined key_top
!CC   ------------------------------------------------------------------
!CC
!CC   ROUTINE bgcnul : DGOM MODEL
!CC   *****************************
!CC
!C
!C     PURPOSE.
!C     --------
!C                   Sets some processes to zero to protect passive
!C                   tracers from going negative.
!C     EXTERNALS.
!C     ----------
!C          NONE.
!C
!C   MODIFICATIONS:
!C   --------------
!C      original p4znull : 2002    E. Buitenhuis
!C ---------------------------------------------------------------------
      USE trp_trc
      USE sms
      USE oce_trc
      IMPLICIT NONE
! local declarations
      INTEGER ji, jj, jk, jl, jm
      REAL xcond,phosph2,zoo2,mes2,dsil2,doc212
      REAL bac212,biron2,bsil2,din2,goc212,iron2,mac2,phyto2,poc212,siron2
      REAL consum,nitrfac,zlosss,zprotec,zminc
      REAL dmd212, dms212
#  include "domzgr_substitute.h90"
!
!  minimum concentration for PFT biomass
!   
      zminc = 1.e-10
!
!     Vertical loop to pre-compute concentration changes of the (rapidly
!     varying) tracers for preventing them to fall below 0
!     ------------------------------------------------------------------
!
      DO jk = 1, jpk-1
        DO jj = 2, nlcj-1
          DO ji = 2, nlci-1
            consum=(1.-bactge(ji,jj,jk))*(olimi(ji,jj,jk)               &
     &        +orem(ji,jj,jk)+orem2(ji,jj,jk))                          &
     &        +grarem(ji,jj,jk)*rn_sigmic+grarem2(ji,jj,jk)*rn_sigmes   &
     &        +grarem3(ji,jj,jk)*rn_sigmac                              &
     &        +respz(ji,jj,jk)+respz2(ji,jj,jk)+respz3(ji,jj,jk)        &
     &        +resbac(ji,jj,jk)/3.0
            DO jl = jpdia, jpdia+jppft-1
              consum = consum +resphy(ji,jj,jk,jl,1)
            END DO
            nitrfac=max(-0.5,(rn_doxden-trno2(ji,jj,jk))            &
     &        /(2*rn_doxden+trno2(ji,jj,jk)))
            nitrfac=(sin(nitrfac*rpi)+1.)/2.
! C122N16H120 + 172 O2 -> 122 CO2 + 52 H2O + 16 HNO3
! 0.8 HNO3 -> 0.4 N2 + O2 + 0.4 H2O
            delo2(ji,jj,jk)=rato2c*consum*(1.-nitrfac)
            denitr(ji,jj,jk)=0.8*(rato2c*consum-delo2(ji,jj,jk))
!     
!     Evolution of PO4
!     ----------------
!     
            zlosss = 0.
            DO jl = jpdia, jpdia+jppft-1
              zlosss = zlosss +prophy(ji,jj,jk,jl,1)+docphy(ji,jj,jk,jl)
            END DO 
            phosph2 = trn(ji,jj,jk,jppo4)+consum &
     &       +deppo4(ji,jj,jk)
!     
!     Nullity test for PO4
!     --------------------
!     
            zprotec=max(0.,min(1.,(phosph2-1e-10)/(zlosss+rtrn)))
            DO jl = jpdia, jpdia+jppft-1
              prophy(ji,jj,jk,jl,1)=prophy(ji,jj,jk,jl,1)*zprotec
              docphy(ji,jj,jk,jl)  =docphy(ji,jj,jk,jl)  *zprotec
            END DO
!
!     Evolution of DIN
!     ----------------
!
            din2 = trn(ji,jj,jk,jpno3) &
     &        +consum*ratn2c+depno3(ji,jj,jk)-1e-10
!
            zlosss = 0.
            DO jl = jpdia, jpdia+jppft-1
              zlosss =zlosss+(prophy(ji,jj,jk,jl,1)+docphy(ji,jj,jk,jl))&
     &          *ratn2c*dinpft(ji,jj,jk,jl)*pnophy(ji,jj,jk,jl)
            END DO
!
!     Nullity test for DIN
!     --------------------
!
            zprotec = max(0.,min(1.,din2/(zlosss+rtrn)))
            DO jl = jpdia, jpdia+jppft-1
              prophy(ji,jj,jk,jl,1)=prophy(ji,jj,jk,jl,1)*zprotec
              docphy(ji,jj,jk,jl)  =docphy(ji,jj,jk,jl)  *zprotec
            END DO
!     if denitr > din2+consum decrease consum of (O2+macronutrient)
            xcond=(0.5+sign(0.5,din2-zlosss*zprotec-denitr(ji,jj,jk)))
            din2 = trn(ji,jj,jk,jpno3)+depno3(ji,jj,jk)                 &
     &        -zlosss*zprotec-1e-10
            zprotec = max(xcond,min(1.,din2*(0.8*rato2c)/ &
     &        ((0.8*rato2c*ratc2n-1.)*denitr(ji,jj,jk)+rtrn)))
            olimi(ji,jj,jk) = olimi(ji,jj,jk)*zprotec
            orem(ji,jj,jk) = orem(ji,jj,jk)*zprotec
            orem2(ji,jj,jk) = orem2(ji,jj,jk)*zprotec
            grazg(ji,jj,jk) = grazg(ji,jj,jk)*zprotec
            grazm(ji,jj,jk) = grazm(ji,jj,jk)*zprotec
            grazz(ji,jj,jk) = grazz(ji,jj,jk)*zprotec
            grazpoc(ji,jj,jk) = grazpoc(ji,jj,jk)*zprotec
            grazgoc(ji,jj,jk) = grazgoc(ji,jj,jk)*zprotec
            gramam(ji,jj,jk) = gramam(ji,jj,jk)*zprotec
            gramaz(ji,jj,jk) = gramaz(ji,jj,jk)*zprotec
            grambac(ji,jj,jk) = grambac(ji,jj,jk)*zprotec
            grampoc(ji,jj,jk) = grampoc(ji,jj,jk)*zprotec
            gramgoc(ji,jj,jk) = gramgoc(ji,jj,jk)*zprotec
            DO jl = jpdia, jpdia+jppft-1
              DO jm = 1, 3
                gramic(ji,jj,jk,jl,jm) = gramic(ji,jj,jk,jl,jm)*zprotec
                grames(ji,jj,jk,jl,jm) = grames(ji,jj,jk,jl,jm)*zprotec
                gramac(ji,jj,jk,jl,jm) = gramac(ji,jj,jk,jl,jm)*zprotec
                resphy(ji,jj,jk,jl,jm) = resphy(ji,jj,jk,jl,jm)*zprotec
              END DO
            END DO
            respz(ji,jj,jk) = respz(ji,jj,jk)*zprotec
            respz2(ji,jj,jk) = respz2(ji,jj,jk)*zprotec
            respz3(ji,jj,jk) = respz3(ji,jj,jk)*zprotec
            resbac(ji,jj,jk) = resbac(ji,jj,jk)*zprotec
!
!     Evolution of dissolved Iron
!     ------------------------------------------------------------------
!
            iron2 = trn(ji,jj,jk,jpfer)                               &
     &       +ferat3*(respz(ji,jj,jk)+respz2(ji,jj,jk)+respz3(ji,jj,jk)&
     &       +morbac(ji,jj,jk))&
     &       +grafer(ji,jj,jk)+grafer2(ji,jj,jk)+grafer3(ji,jj,jk)      &
     &        +ofer(ji,jj,jk)+ofer2(ji,jj,jk)                           &
     &       +rbafer(ji,jj,jk)+irondep(ji,jj,jk)+depfer(ji,jj,jk)
            DO jl = jpdia, jpdia+jppft-1
              iron2 = iron2 + resphy(ji,jj,jk,jl,2)
            ENDDO
!
            zlosss = ubafer(ji,jj,jk)+xscave(ji,jj,jk)
            DO jl = jpdia, jpdia+jppft-1
              zlosss = zlosss +prophy(ji,jj,jk,jl,2)
            END DO
!
!     Nullity test for Iron
!     ---------------------
!
            zprotec =max(0.,min(1.,(iron2-1e-13)/(zlosss+rtrn)))
            DO jl = jpdia, jpdia+jppft-1
              prophy(ji,jj,jk,jl,1)=prophy(ji,jj,jk,jl,1)*zprotec
              prophy(ji,jj,jk,jl,2)=prophy(ji,jj,jk,jl,2)*zprotec
              prophy(ji,jj,jk,jl,3)=prophy(ji,jj,jk,jl,3)*zprotec
            END DO
            ubafer(ji,jj,jk) = ubafer(ji,jj,jk)*zprotec
!    
!     Evolution of phytoplankton
!     ------------------------------------------------------------------
!     
              DO jl = jpdia, jpdia+jppft-1
                DO jm = 1, 3
                phyto2 = trn(ji,jj,jk,jl+(jm-1)*jppft)          &
     &          +prophy(ji,jj,jk,jl,jm)                                 &
     &          -gramic(ji,jj,jk,jl,jm)-grames(ji,jj,jk,jl,jm)          &
     &          -gramac(ji,jj,jk,jl,jm)                                 &
     &          -resphy(ji,jj,jk,jl,jm)
!     
!     Nullity test for Phyto
!     ----------------------
!     
                xcond=(0.5+sign(0.5,phyto2))
                gramic(ji,jj,jk,jl,jm)=gramic(ji,jj,jk,jl,jm)*xcond
                grames(ji,jj,jk,jl,jm)=grames(ji,jj,jk,jl,jm)*xcond
                gramac(ji,jj,jk,jl,jm)=gramac(ji,jj,jk,jl,jm)*xcond
                resphy(ji,jj,jk,jl,jm)=resphy(ji,jj,jk,jl,jm)*xcond
                END DO
              END DO
!
!     Nullity test for SiO3
!     ---------------------
!
              dsil2 = trn(ji,jj,jk,jpsil)+osil(ji,jj,jk)                &
     &        +depsil(ji,jj,jk)+sidep(ji,jj,jk)
              zlosss = prorca3(ji,jj,jk)
              zprotec =max(0.,min(1.,(dsil2-1e-10)/(zlosss+rtrn)))
              prorca3(ji,jj,jk)=prorca3(ji,jj,jk)*zprotec
!
!     Evolution of biogenic Silica in diatoms
!     ---------------------------------------
!
              bsil2 = trn(ji,jj,jk,jpbsi)+prorca3(ji,jj,jk)             &
     &        -resps(ji,jj,jk)-grazs(ji,jj,jk)-grazss(ji,jj,jk)         &
     &        -grasss(ji,jj,jk)
!
!     Nullity test for Biogenic Silica in Diatoms
!     -------------------------------------------
!
              xcond=(0.5+sign(0.5,bsil2))
              resps(ji,jj,jk)=resps(ji,jj,jk)*xcond
              grazs(ji,jj,jk)=grazs(ji,jj,jk)*xcond
              grazss(ji,jj,jk)=grazss(ji,jj,jk)*xcond
              grasss(ji,jj,jk)=grasss(ji,jj,jk)*xcond
!    
!     Evolution of Microzooplankton
!     ------------------------
!    
              zlosss = gramaz(ji,jj,jk)+grazz(ji,jj,jk)+tormic(ji,jj,jk)+respz(ji,jj,jk)        
              zoo2 = trn(ji,jj,jk,jpmic)+micrge(ji,jj,jk)*gramit(ji,jj,jk)
!    
!     Nullity test for Microzooplankton
!     ----------------------------
!    
              zprotec=max(0.,min(1.,(zoo2-zminc)/(zlosss+rtrn)))
              tormic(ji,jj,jk)=tormic(ji,jj,jk)*zprotec
              respz(ji,jj,jk)=respz(ji,jj,jk)*zprotec
              grazz(ji,jj,jk)=grazz(ji,jj,jk)*zprotec
              gramaz(ji,jj,jk)=gramaz(ji,jj,jk)*zprotec
!
!     Evolution of Mesozooplankton
!     ----------------------------
!
              zlosss = gramam(ji,jj,jk)+tormes(ji,jj,jk)+respz2(ji,jj,jk)
              mes2 = trn(ji,jj,jk,jpmes)+mesoge(ji,jj,jk)*gramet(ji,jj,jk) 
!
!     Nullity test for Mesozooplankton
!     --------------------------------
!
              zprotec=max(0.,min(1.,(mes2-zminc)/(zlosss+rtrn)))
              respz2(ji,jj,jk)=respz2(ji,jj,jk)*zprotec
              tormes(ji,jj,jk)=tormes(ji,jj,jk)*zprotec
              gramam(ji,jj,jk)=gramam(ji,jj,jk)*zprotec
!
!     Evolution of Macrozooplankton
!     -----------------------------
!
              zlosss = tormac(ji,jj,jk)+respz3(ji,jj,jk)
              mac2 = trn(ji,jj,jk,jpmac)+macrge(ji,jj,jk)*gramat(ji,jj,jk) 
!
!     Nullity test for Macrozooplankton
!     ---------------------------------
!
              zprotec=max(0.,min(1.,(mac2-zminc)/(zlosss+rtrn)))
              respz3(ji,jj,jk)=respz3(ji,jj,jk)*zprotec
              tormac(ji,jj,jk)=tormac(ji,jj,jk)*zprotec
!
!     Nullity test for DOC
!     --------------------------------
!
          doc212 = trn(ji,jj,jk,jpdoc)                                  &
     &        +grarem(ji,jj,jk)*(1.-rn_sigmic)+grarem2(ji,jj,jk)        &
     &        *(1.-rn_sigmes)+grarem3(ji,jj,jk)*(1.-rn_sigmac)          &
     &        +depdoc(ji,jj,jk)                                         &
     &        +resbac(ji,jj,jk)/3.0 
          zlosss = olimi(ji,jj,jk)+xaggdoc(ji,jj,jk)+xaggdoc2(ji,jj,jk)
          zprotec =max(0.,min(1.,(doc212-1e-10)/(zlosss+rtrn)))
          olimi(ji,jj,jk)=olimi(ji,jj,jk)*zprotec
          xaggdoc(ji,jj,jk)=xaggdoc(ji,jj,jk)*zprotec
          xaggdoc2(ji,jj,jk)=xaggdoc2(ji,jj,jk)*zprotec
!
!     Bacteria
!     --------
          bac212 = trn(ji,jj,jk,jpbac)+bactge(ji,jj,jk)* &
     &      (olimi(ji,jj,jk)+orem(ji,jj,jk)+orem2(ji,jj,jk))
          zlosss = resbac(ji,jj,jk)+grabac(ji,jj,jk)+grazbac(ji,jj,jk)+grambac(ji,jj,jk)+morbac(ji,jj,jk)
          zprotec =max(0.,min(1.,(bac212-1e-10)/(zlosss+rtrn)))
          resbac(ji,jj,jk)=resbac(ji,jj,jk)*zprotec
          grabac(ji,jj,jk)=grabac(ji,jj,jk)*zprotec
          grazbac(ji,jj,jk)=grazbac(ji,jj,jk)*zprotec
          grambac(ji,jj,jk)=grambac(ji,jj,jk)*zprotec
          morbac(ji,jj,jk)=morbac(ji,jj,jk)*zprotec
              siron2=trn(ji,jj,jk,jpsfe)
              biron2=trn(ji,jj,jk,jpbfe)
              DO jl = jpdia, jpdia+jppft-1
                siron2=siron2+rn_unamic*gramic(ji,jj,jk,jl,2)
                biron2=biron2+rn_unames*grames(ji,jj,jk,jl,2)           &
     &            +rn_unamac*gramac(ji,jj,jk,jl,2)
              END DO
!
!     Evolution of big POC
!     --------------------
!
              goc212 = trn(ji,jj,jk,jpgoc)                              &
     &       +grapoc2(ji,jj,jk)+grapoc3(ji,jj,jk)                       &
     &       +tormes(ji,jj,jk)+tormac(ji,jj,jk)                         &
     &       +xagg(ji,jj,jk)+xaggdoc2(ji,jj,jk)                         &
     &       -grazgoc(ji,jj,jk)-gramgoc(ji,jj,jk)-orem2(ji,jj,jk)       &
     &       -grazg(ji,jj,jk)                                           &
     &       +(sinking2(ji,jj,jk)-sinking2(ji,jj,jk+1))/fse3t(ji,jj,jk)
!
!     Nullity test for GOC
!     --------------------
!
              xcond=(0.5+sign(0.5,goc212))
              sinking2(ji,jj,jk+1)=sinking2(ji,jj,jk+1)*xcond
              orem2(ji,jj,jk)=orem2(ji,jj,jk)*xcond
              grazg(ji,jj,jk)=grazg(ji,jj,jk)*xcond
              grazgoc(ji,jj,jk)=grazgoc(ji,jj,jk)*xcond
              gramgoc(ji,jj,jk)=gramgoc(ji,jj,jk)*xcond
!     
!     Evolution of small POC
!     ----------------------
!     
              poc212 = trn(ji,jj,jk,jppoc)+grapoc(ji,jj,jk)             &
     &       +tormic(ji,jj,jk) -grazpoc(ji,jj,jk)-grampoc(ji,jj,jk)      &
     &          -grazm(ji,jj,jk)-orem(ji,jj,jk)                         &
     &       -xagg(ji,jj,jk)+xaggdoc(ji,jj,jk)+deppoc(ji,jj,jk)         &
     &       +(sinking(ji,jj,jk)-sinking(ji,jj,jk+1))/fse3t(ji,jj,jk)   &
     &        +resbac(ji,jj,jk)/3.0 
!     
!     Nullity test for POC
!     --------------------
!     
              xcond=(0.5+sign(0.5,poc212))
              grazm(ji,jj,jk)=grazm(ji,jj,jk)*xcond
              sinking(ji,jj,jk+1)=sinking(ji,jj,jk+1)*xcond
              orem(ji,jj,jk)=orem(ji,jj,jk)*xcond
              xagg(ji,jj,jk)=xagg(ji,jj,jk)*xcond
              grazpoc(ji,jj,jk)=grazpoc(ji,jj,jk)*xcond
              grampoc(ji,jj,jk)=grampoc(ji,jj,jk)*xcond
!
!     Evolution of small biogenic Iron
!     ------------------------------------------------------------------
!
              siron2 = siron2                                           &
     &        +ferat3*(tormic(ji,jj,jk)+rn_unamic*grabac(ji,jj,jk)      &
     &        +rn_unames*grazbac(ji,jj,jk)                              &
     &        +deppoc(ji,jj,jk))+rn_unamic*grazgf(ji,jj,jk)             &
     &        -(1.-rn_unamic)*grazmf(ji,jj,jk)-ofer(ji,jj,jk)           &
     &        -grampof(ji,jj,jk)-grazpof(ji,jj,jk)                      &
     &        -xaggfe(ji,jj,jk)+scasfe(ji,jj,jk)                        &
     &        +(sinkfer(ji,jj,jk)-sinkfer(ji,jj,jk+1))/fse3t(ji,jj,jk)
!
!     Nullity test for small biogenic iron
!     --------------------
!
              xcond=(0.5+sign(0.5,siron2))
              sinkfer(ji,jj,jk+1)=sinkfer(ji,jj,jk+1)*xcond
              ofer(ji,jj,jk) = ofer(ji,jj,jk)*xcond
              xaggfe(ji,jj,jk)=xaggfe(ji,jj,jk)*xcond
              grazmf(ji,jj,jk)=grazmf(ji,jj,jk)*xcond
              grazpof(ji,jj,jk)=grazpof(ji,jj,jk)*xcond
              grampof(ji,jj,jk)=grampof(ji,jj,jk)*xcond
!
!     Evolution of big biogenic Iron
!     --------------------------
!
              biron2 = biron2                                           &
     &        +rn_unames*grazpof(ji,jj,jk)+rn_unamac*grampof(ji,jj,jk)  &
     &        +ferat3*(tormes(ji,jj,jk)+tormac(ji,jj,jk)                &
     &        +rn_unames*grazz(ji,jj,jk)+rn_unamac*(gramam(ji,jj,jk)    &
     &        +gramaz(ji,jj,jk)+grambac(ji,jj,jk)))                     &
     &        +xaggfe(ji,jj,jk)+scabfe(ji,jj,jk)-ofer2(ji,jj,jk)        &
     &        -grazgf(ji,jj,jk)-(1.-rn_unames)*grazgof(ji,jj,jk)        &
     &        -(1.-rn_unamac)*gramgof(ji,jj,jk)                         &
     &        +(sinkfer2(ji,jj,jk)-sinkfer2(ji,jj,jk+1))/fse3t(ji,jj,jk)
!
!     Nullity test for big biogenic iron
!     --------------------
!
              xcond=(0.5+sign(0.5,biron2))
              sinkfer2(ji,jj,jk+1)=sinkfer2(ji,jj,jk+1)*xcond
              ofer2(ji,jj,jk) = ofer2(ji,jj,jk)*xcond
              grazgf(ji,jj,jk)=grazgf(ji,jj,jk)*xcond
              grazgof(ji,jj,jk)=grazgof(ji,jj,jk)*xcond
              gramgof(ji,jj,jk)=gramgof(ji,jj,jk)*xcond
!
!     Evolution of sinking biogenic silica
!     --------------------------
!
               dsil2=trn(ji,jj,jk,jpdsi)                           &
     &         +resps(ji,jj,jk)-osil(ji,jj,jk)                          &
     &         +grazs(ji,jj,jk)+grazss(ji,jj,jk)+grasss(ji,jj,jk)       &
     &         +(sinksil(ji,jj,jk)-sinksil(ji,jj,jk+1))/fse3t(ji,jj,jk)
!
!     Nullity test for sinking biogenic Silica
!     --------------------------------
!
               xcond=(0.5+sign(0.5,dsil2))
               sinksil(ji,jj,jk+1)=sinksil(ji,jj,jk+1)*xcond
               osil(ji,jj,jk)=osil(ji,jj,jk)*xcond
!
!     Protection of CaCO3 concentration
!     --------------------------------
!
               sinkcal(ji,jj,jk+1) = min(trn(ji,jj,jk,jpcal), &
     &           sinkcal(ji,jj,jk+1)/fse3t(ji,jj,jk+1))*fse3t(ji,jj,jk+1)
!
!     Protection of DMS(Pd)
!     --------------------------
!
!            dmd212 = trn(ji,jj,jk,jpdmd)+prodmd(ji,jj,jk)
!            zlosss = degdmd(ji,jj,jk)
!            zprotec= max(0.,min(1.,(dmd212-1.e-12)/(zlosss+rtrn)))
!            if ( zprotec .gt. 1.-1.e-12 .or. &
!     &           zprotec .lt. 1.+1.e-12 ) dmd_snkcount=dmd_snkcount+1   
!            degdmd(ji,jj,jk) = degdmd(ji,jj,jk)*zprotec
!            dmddms(ji,jj,jk) = dmddms(ji,jj,jk)*zprotec
!            dms212 = trn(ji,jj,jk,jpdms)+prodms(ji,jj,jk)+dmddms(ji,jj,jk)
!            zlosss = degdms(ji,jj,jk)
!            zprotec= max(0.,min(1.,(dms212-1.e-12)/(zlosss+rtrn)))
!            degdms(ji,jj,jk) = degdms(ji,jj,jk)*zprotec
!            if ( zprotec .gt. 1.-1.e-12 .or. &
!     &           zprotec .lt. 1.+1.e-12 ) dms_snkcount=dms_snkcount+1   
          END DO
        END DO
      END DO
#endif
      RETURN
      END
