#if defined key_top
      SUBROUTINE bgcpro
!!!---------------------------------------------------------------------
!!!
!!!                       ROUTINE bgcpro
!!!                     *****************
!!!
!!!  PURPOSE :
!!!  ---------
!!!         Compute the phytoplankton production depending on
!!!         light, temperature and nutrient availability
!!!
!!   METHOD :
!!   -------
!!      
!!
!!   INPUT :
!!   -----
!!      argument
!!              None
!!      common
!!              all the common defined in opa
!!
!!
!!   OUTPUT :                   : no
!!   ------
!!
!!   WORKSPACE :
!!   ---------
!!
!!   EXTERNAL :
!!   --------
!!
!!   MODIFICATIONS:
!!   --------------
!!      original  p4zprod : O. Aumont (2002) 
!!      modifications     : E. Buitenhuis(2002)
!!----------------------------------------------------------------------
      USE trc
      USE trp_trc
      USE sms
      USE oce_trc
      USE traqsr  , ONLY : ln_qsr_sms
      IMPLICIT NONE
! local declarations
      INTEGER ji, jj, jk, jl
      REAL silpot1,silpot2,silfac,pislopen,ysopt
      REAL parlux,ekg,ekr,xlim1,xlim2,xlim3,xlim4(jpdia:jpdia+jppft-1)
      REAL xlim5(jpdia:jpdia+jppft-1),xlim6(jpdia:jpdia+jppft-1)
      REAL dinlim(jpdia:jpdia+jppft-1),prodt
      REAL xlim7,xlim8
      REAL e1(jpi,jpj,jpk),e2(jpi,jpj,jpk)      
! local dgom variables
      REAL pcphot(jpdia:jpdia+jppft-1),quopfe(jpdia:jpdia+jppft-1)
      REAL rhochl(jpdia:jpdia+jppft-1),vcfer(jpdia:jpdia+jppft-1)
      REAL perfrm(jpdia:jpdia+jppft-1)
      REAL pcmax(jpdia:jpdia+jppft-1)
      REAL pctnut,docpro
      REAL xlimpft(jpi,jpj,jpk,jpdia:jpdia+jppft-1)
      REAL xdenom,xlinh4,xlino3,zmask,zkrdphy
!
#  include "domzgr_substitute.h90"
!
      IF (.NOT. ln_qsr_sms ) THEN
!     Initialisation of variables used to compute PAR
!     Note: parlux is half of the visible light
!     -----------------------------------------------
!
        parlux      = 0.215
!
        DO jj = 2, nlcj-1
          DO ji = 2, nlci-1
            e1(ji,jj,1)=parlux*qsr(ji,jj)
            e2(ji,jj,1)=e1(ji,jj,1)
          END DO
        END DO
        DO jk = 1, jpk-1
          DO jj = 2, nlcj-1
            DO ji = 2, nlci-1
! PFT specific extinction as in Manizza 2006
              ekr = rn_ekwred 
              ekg = rn_ekwgrn 
!
              DO jl = jpdia, jpdia+jppft-1
!
                ekr = ekr + (trn(ji,jj,jk,jl+2*jppft)*rn_krdphy(jl)*1.E6)
                ekg = ekg + (trn(ji,jj,jk,jl+2*jppft)*rn_kgrphy(jl)*1.E6)
!
              END DO
              extpar(ji,jj,jk)=ekr+ekg
!
              e1(ji,jj,jk+1) = e1(ji,jj,jk)*exp(-ekg*fse3t(ji,jj,jk)/2.)
              e2(ji,jj,jk+1) = e2(ji,jj,jk)*exp(-ekr*fse3t(ji,jj,jk)/2.)
              etot(ji,jj,jk) = 3.99*e1(ji,jj,jk+1)+5.24*e2(ji,jj,jk+1)
!
!     Computation of irradiance below level T
!     ---------------------------------------
!
              e1(ji,jj,jk+1) = e1(ji,jj,jk+1)*exp(-ekg*fse3t(ji,jj,jk)/2.)
              e2(ji,jj,jk+1) = e2(ji,jj,jk+1)*exp(-ekr*fse3t(ji,jj,jk)/2.)
            END DO
          END DO
        END DO
      ENDIF
!
      DO jl = jpdia, jpdia+jppft-1
        pcmax(jl) = rn_mumpft(jl)*(1.+rn_resphy(jl))/rjjss
      END DO
!
      DO jl = jpdia+1, jpdia+jppft-1
        xlim5(jl)=1.
      END DO
      xlim6(jpfix)=rn_munfix!LaRoche test
      DO jk = 1, jpk-1
        DO jj = 2, nlcj-1
          DO ji = 2, nlci-1
!
!      Michaelis-Menten Limitation term for nutrients with threshold for growth at 0.1*k-half
!      -----------------
! Diatoms
             jl = jpdia
             xlim5(jl)=trn(ji,jj,jk,jpsil)/(trn(ji,jj,jk,jpsil)+rn_sildia)
! LaRoche test: Nfixers don't use fixed N, uncomment next line
!           DO jl = jpdia, jpdia+jppft-2
           DO jl = jpdia, jpdia+jppft-1
             xlim4(jl)=trn(ji,jj,jk,jppo4)/(trn(ji,jj,jk,jppo4)+rn_kmpphy(jl))
             xdenom=1./(rn_kmnphy(jl)*rn_kmhphy(jl)                     &
     &         +rn_kmhphy(jl)*trn(ji,jj,jk,jpno3)                       &
     &         +rn_kmnphy(jl)*trn(ji,jj,jk,jpnh4))
             xlino3=trn(ji,jj,jk,jpno3)*rn_kmhphy(jl)*xdenom
             xlinh4=trn(ji,jj,jk,jpnh4)*rn_kmnphy(jl)*xdenom
             xlim6(jl)=xlino3+xlinh4
             dinlim(jl) = xlim6(jl)
             pnophy(ji,jj,jk,jl)=xlino3/max(xlim6(jl),rtrn)
           END DO
!    Michaelis-Menten Limitation term for nutrients for bacteria -
! for use in degradation of DMS
            xlim1=trn(ji,jj,jk,jppo4)/(trn(ji,jj,jk,jppo4)+rn_kmpbac)
            xlim2=trn(ji,jj,jk,jpfer)/(trn(ji,jj,jk,jpfer)+rn_kmfbac)
            xlim3=trn(ji,jj,jk,jpdoc)/(trn(ji,jj,jk,jpdoc)+rn_kmobac)
            xlimbac(ji,jj,jk)=min(xlim1,xlim2,xlim3)
! N2 fixers
           jl = jpfix
! LaRoche test: Nfixers don't use fixed N, uncomment next line
!             xlim4(jl)=trn(ji,jj,jk,jppo4)/(trn(ji,jj,jk,jppo4)+rn_kmpphy(jl))
! LaRoche test: Nfixers don't use fixed N, comment next 4 lines
             xlim6(jl)= dinlim(jl) +rn_munfix*(1.-dinlim(jl))
             pnophy(ji,jj,jk,jl)=xlino3/max(xlim6(jl),rtrn)
             dinpft(ji,jj,jk,jl)=dinlim(jl)/(xlim6(jl)+rtrn)*tmask(ji,jj,jk)
!
             alpthe(ji,jj,jk)=0.
             prodt=0.
           DO jl = jpdia, jpdia+jppft-1
!
! quota model for Fe-light
!
            quopfe(jl) =max(min(trn(ji,jj,jk,jl+jppft)/(trn(ji,jj,jk,jl)&
     &        +rtrn),rn_qmaphy(jl)),rn_qmiphy(jl))
            xlim1 = (rn_rhfphy(jl)*rn_qmaphy(jl)-rn_qmaphy(jl))*    &
     &        (rn_qmaphy(jl)-quopfe(jl))/                           &
     &        (rn_qmaphy(jl)-rn_qmiphy(jl))+rn_qmaphy(jl)
            xlim2 = trn(ji,jj,jk,jpfer)/(trn(ji,jj,jk,jpfer)+       &
     &        rn_kmfphy(jl))
            xlim3 =min((quopfe(jl)-rn_qmiphy(jl))                       &
     &        /(rn_qopphy(jl)-rn_qmiphy(jl)),1.)*(1.+rn_nutthe)-rn_nutthe
            xlim7 = (etot(ji,jj,jk)-rn_tliphy(jl))*rn_nutthe/       &
     &        (etot(ji,jj,jk)+rn_tliphy(jl)*(1.-rn_nutthe))
!
! ensure growth is zero if nutrient concentration is below threshold
!
            xlimpft(ji,jj,jk,jl)=max(min(xlim4(jl),xlim5(jl),xlim6(jl),xlim3),0.)
! 
! Fe uptake rate 
!
            vcfer(jl) = rn_mumpft(jl)*(1.+rn_resphy(jl))                   &
     &        *xlim1*min(xlim4(jl),xlim5(jl),xlim6(jl),xlim2)
            vcfer(jl) = max(vcfer(jl),0.)
!
! 4.6 micromol photons/J at 550 nm
!
            perfrm(jl)=max(rn_alpphy(jl)*trn(ji,jj,jk,jl+2*jppft)       &
     &        *(etot(ji,jj,jk)-rn_tliphy(jl))/(trn(ji,jj,jk,jl)+rtrn),0.)
            alpthe(ji,jj,jk)=alpthe(ji,jj,jk)+rn_alpphy(jl)*trn(ji,jj,jk,jl+2*jppft)/(trn(ji,jj,jk,jl)+rtrn)
            docpro=rn_docphy(jl)+(1.-xlimpft(ji,jj,jk,jl))*rn_domphy(jl)
            pctnut=pcmax(jl)*xlimpft(ji,jj,jk,jl)*tgfunc(ji,jj,jk,jl)
! light limitation
            xlim8      = (1.-exp(-perfrm(jl)/(pctnut+rtrn)))
            pcphot(jl) = pctnut*xlim8
            rhochl(jl)=rn_thmphy(jl)*pcphot(jl)/(perfrm(jl)+rtrn)
!
! synthesis rates
!
            prophy(ji,jj,jk,jl,3) = rhochl(jl)*pcphot(jl)               &
     &        *trn(ji,jj,jk,jl)*rfact
            prophy(ji,jj,jk,jl,2) = vcfer(jl)*xlim8*tgfunc(ji,jj,jk,jl) &
     &        *trn(ji,jj,jk,jl)*rfact/rjjss
            prophy(ji,jj,jk,jl,1) = pcphot(jl)*trn(ji,jj,jk,jl)*rfact
            docphy(ji,jj,jk,jl)   = prophy(ji,jj,jk,jl,1)*docpro
            prodt=prodt+(prophy(ji,jj,jk,jl,1)+docphy(ji,jj,jk,jl))*(1.-dinlim(jl))
           END DO
!
!    FE/C and Si/C of diatoms
!    ------------------------
!    Si/C increases with iron stress and silicate availability
!    Si/C is arbitrariliy increased for very high Si concentrations
!    to mimic the very high ratios observed in the Southern Ocean
!    (silpot2)
!
            silpot1=(4.-3.*min(max(0.,trn(ji,jj,jk,jpfer)) &
     &        /rn_kmfphy(jpdia),1.))
            silpot2=6.*trn(ji,jj,jk,jpsil)/(trn(ji,jj,jk,jpsil)+rn_kmsbsi)
            silfac=max(silpot1,silpot2)
            ysopt=0.15*min(1.,trn(ji,jj,jk,jpsil)/rn_sildia)*silfac
            prorca3(ji,jj,jk) = prophy(ji,jj,jk,jpdia,1)*ysopt* &
     &        tmask(ji,jj,jk)
          END DO
        END DO
      END DO
      RETURN
      END
#endif
