      SUBROUTINE bgcsed
#if defined key_top
!CC---------------------------------------------------------------------
!CC
!CC                       ROUTINE bgcsed
!CC                     *****************
!CC
!CC  PURPOSE :
!CC  ---------
!CC         Compute loss of organic matter in the sediments. This
!CC         is by no way a sediment model. The loss is simply 
!CC         computed to balance the input from rivers and dust
!CC
!C   METHOD :
!C   -------
!C      
!C
!C   INPUT :
!C   -----
!C
!C   OUTPUT :                   : no
!C   ------
!C
!C   WORKSPACE :
!C   ---------
!C
!C   EXTERNAL :
!C   --------
!C
!C   MODIFICATIONS:
!C   --------------
!C      original  : O. Aumont 
!C----------------------------------------------------------------------
      USE trp_trc
      USE sms
      USE oce_trc
      USE lib_mpp
      IMPLICIT NONE
!C
!C local declarations
!C ==================
      INTEGER ji, jj, jk, ikt, jp
      REAL sumsed(5),sumqua(5),botcor(5)
      REAL delno3,denitot,nitrpottot,nitrpot(jpi,jpj)
#  include "domzgr_substitute.h90"
!
!    Loss of material in the sediments. 
!    First, the total amount in the bottom layer is computed.
!    -------------------------------------------------------------------
!
      sumsed=0.
      sumqua=0.
      DO jj = 2, nlcj-1
        DO ji = 2, nlci-1
          ikt=max(mbathy(ji,jj)-1,1)
          sumsed(1)=sumsed(1)+trn(ji,jj,ikt,jpdsi)*1000. &
     &      *e1t(ji,jj)*e2t(ji,jj)*fse3t(ji,jj,ikt)
          sumsed(2)=sumsed(2)+(trn(ji,jj,ikt,jpgoc)+                  &
     &      trn(ji,jj,ikt,jppoc))*1000.*e1t(ji,jj)*e2t(ji,jj)*fse3t(ji,jj,ikt)
          sumsed(3)=sumsed(3)+(trn(ji,jj,ikt,jpbfe)+                    &
     &      trn(ji,jj,ikt,jpsfe))*1000.*e1t(ji,jj)*e2t(ji,jj)*fse3t(ji,jj,ikt)
          sumsed(4)=sumsed(4)+trn(ji,jj,ikt,jpdoc)*1000. &
     &      *e1t(ji,jj)*e2t(ji,jj)*fse3t(ji,jj,ikt)
          sumsed(5)=sumsed(5)+2.*trn(ji,jj,ikt,jpcal)*1000. &
     &      *e1t(ji,jj)*e2t(ji,jj)*fse3t(ji,jj,ikt)
          sumqua(1)=sumqua(1)+trn(ji,jj,ikt,jpdsi)**2*1000. &
     &      *e1t(ji,jj)*e2t(ji,jj)*fse3t(ji,jj,ikt)
          sumqua(2)=sumqua(2)+(trn(ji,jj,ikt,jpgoc)+                  &
     &      trn(ji,jj,ikt,jppoc))**2*1000.*e1t(ji,jj)*e2t(ji,jj)*fse3t(ji,jj,ikt)
          sumqua(3)=sumqua(3)+(trn(ji,jj,ikt,jpbfe)+                    &
     &      trn(ji,jj,ikt,jpsfe))**2*1000.*e1t(ji,jj)*e2t(ji,jj)*fse3t(ji,jj,ikt)
          sumqua(4)=sumqua(4)+(trn(ji,jj,ikt,jpdoc)+                    &
     &      trn(ji,jj,ikt,jpdoc))**2*1000.*e1t(ji,jj)*e2t(ji,jj)*fse3t(ji,jj,ikt)
          sumqua(5)=sumqua(5)+2.*trn(ji,jj,ikt,jpcal)**2*1000. &
     &      *e1t(ji,jj)*e2t(ji,jj)*fse3t(ji,jj,ikt)
        END DO
      END DO
      IF( lk_mpp ) CALL mpp_sum( sumsed,5 )
      IF( lk_mpp ) CALL mpp_sum( sumqua,5 )
!
!    Then the amount lost in the sediments equals
!    the external input at the surface (dust+rivers)
!
!     IF (lwp) THEN
!        ikt=max(mbathy(19,29)-1,1)
!        write(numout,*) "ikt:",ikt,trn(19,29,ikt,jpdsi),trn(19,29,ikt+1,jpdsi)
!     ENDIF
     IF (lwp) write(numout,31) "sedimentation:", (sumsed(jp)*1.e-12,jp=1,5)
31   FORMAT(a14,2x,7f10.3)
!      IF (lwp) CALL FLUSH(numout)
      DO ji = 1, 5
        IF (extinp(ji) .GT. sumsed(ji)) THEN
          botcor(ji)=sumsed(ji)
          sedcor(ji)=sedcor(ji)+extinp(ji)-sumsed(ji)
        ELSE
          botcor(ji)=extinp(ji)
        ENDIF
      END DO
!
!    The loss is scaled at each bottom grid cell for
!    equilibrating the total budget of material in the ocean.
!    -------------------------------------------------------------------
      DO jj = 2, nlcj-1
        DO ji = 2, nlci-1
          ikt=max(mbathy(ji,jj)-1,1)
          trn(ji,jj,ikt,jpdsi)=trn(ji,jj,ikt,jpdsi) &
     &      -trn(ji,jj,ikt,jpdsi)**2*botcor(1)/sumqua(1)
          trn(ji,jj,ikt,jpgoc)=trn(ji,jj,ikt,jpgoc) &
     &      -trn(ji,jj,ikt,jpgoc)**2*botcor(2)/sumqua(2)
          trn(ji,jj,ikt,jppoc)=trn(ji,jj,ikt,jppoc) &
     &      -trn(ji,jj,ikt,jppoc)**2*botcor(2)/sumqua(2)
!          trn(ji,jj,ikt,jpbfe)=trn(ji,jj,ikt,jpbfe) &
!     &      -trn(ji,jj,ikt,jpbfe)**2*botcor(3)/sumqua(3)
!          trn(ji,jj,ikt,jpsfe)=trn(ji,jj,ikt,jpsfe) &
!     &      -trn(ji,jj,ikt,jpsfe)**2*botcor(3)/sumqua(3)
          trn(ji,jj,ikt,jpdoc)=trn(ji,jj,ikt,jpdoc) &
     &      -trn(ji,jj,ikt,jpdoc)**2*botcor(4)/sumqua(4)
          trn(ji,jj,ikt,jpcal)=trn(ji,jj,ikt,jpcal) &
     &      -trn(ji,jj,ikt,jpcal)**2*botcor(5)/sumqua(5)
        END DO
      END DO
#endif
      RETURN
      END
