      SUBROUTINE bgcsnk
#if defined key_top
!CC---------------------------------------------------------------------
!CC
!CC                       ROUTINE bgcsnk
!CC                     *****************
!CC
!CC  PURPOSE :
!CC  ---------
!CC         Compute vertical flux of particulate matter due to
!CC         gravitational sinking
!CC
!C   METHOD :
!C   -------
!C
!C   INPUT :
!C   -----
!C
!C   OUTPUT :                   : no
!C   ------
!C
!C   WORKSPACE :
!C   ---------
!C
!C   EXTERNAL :
!C   --------
!C
!C   MODIFICATIONS:
!C   --------------
!C      original  : O. Aumont 
!C----------------------------------------------------------------------
      USE trc
      USE trp_trc
      USE sms
      USE oce_trc
      IMPLICIT NONE
! local declarations
      INTEGER ji, jj, jk,jl
      REAL bacfer,ligfer(jpj,jpk),maxlig,remip,remik,zrfe2,xlam1b,xlamfc
      REAL xkeq,xfeequi,siremin,xdens,xvsink,xvtemp,xpack
      REAL xagg1,xagg2,xagg3,xagg4,zdenom
      REAL ztpbac,zmorbac
      REAL zbldmd,xcldmd,xlibad,xlibas,xphdms
!
!     Compute the sum of the preferences
!     ----------------------------------
!
      ztpbac = rn_gbadoc + rn_gbapoc + rn_gbagoc
      DO jj = 2, nlcj-1
        maxlig = min(max(gphit(2,jj)+70.,15.),40.)/40.*rn_ligfer
        do jk = 1, jpk
            ligfer(jj,jk)=0.e-9+max(min(gdept_0(jk)-100.,100.),0.)/100.*maxlig
        end do
      END DO
!
!     Computation of the vertical sinking speed
!     -----------------------------------------
!
      DO jk = 1, jpk-1
        DO jj = 2, nlcj-1
          DO ji = 2, nlci-1
!    
!     Sinking flux of pFe, POC, GOC, BSi, and Cal
!     ------------------------------------------------------------------
!    
         sinking(ji,jj,jk+1) =                       &
     &           rn_snkpoc/rjjss*trn(ji,jj,jk,jppoc) &
     &           *rfact*tmask(ji,jj,jk+1)
         sinkfer(ji,jj,jk+1) =                       &
     &           rn_snkpoc/rjjss*trn(ji,jj,jk,jpsfe) &
     &           *rfact*tmask(ji,jj,jk+1)
!
! 24,200,60 are the molar weight of dry organic material,CaCO3,SiO2
! 1040380,1660000,1245000 are the density of organic material,CaCO3,SiO2
! rn_snkgoc and rn_singoc are derived by fitting sinking speeds 
! calculated with the sedimentation function of Buitenhuis et al. 2001
! to an exponential function 
! maximum density is 1091314 for maximum sinking speed of 10 m/timestep
!
         xpack = 240. 
!        xpack = 24. 
!
         xdens = (trn(ji,jj,jk,jpgoc)*xpack+trn(ji,jj,jk,jpcal)*100.+&
     &     trn(ji,jj,jk,jpdsi)*60.1)*1e6/                           &
     &     MAX(trn(ji,jj,jk,jpgoc)*xpack/1.08                        &
     &     +trn(ji,jj,jk,jpcal)*100./1.335                          &
     &     +trn(ji,jj,jk,jpdsi)*60.1/1.2,rtrn)-rhop(ji,jj,jk)*1000.
!
         xvsink = MIN(rn_singoc*MAX(xdens,dnsmin)**rn_snkgoc,150.)
!
! for diagnostic
!
         xvtemp = (trn(ji,jj,jk,jpgoc)*xpack+trn(ji,jj,jk,jpcal)*100.+&
     &     trn(ji,jj,jk,jpdsi)*60.1)*1e6/                           &
     &     MAX(trn(ji,jj,jk,jpgoc)*xpack/1.08                        &
     &     +trn(ji,jj,jk,jpcal)*100./1.335                          &
     &     +trn(ji,jj,jk,jpdsi)*60.1/1.2,rtrn)
!
         sinking2(ji,jj,jk+1) =                    &
     &            xvsink/rjjss*trn(ji,jj,jk,jpgoc) &
     &            *rfact*tmask(ji,jj,jk+1)
!
         sinkfer2(ji,jj,jk+1) =                      &
     &              xvsink/rjjss*trn(ji,jj,jk,jpbfe) &
     &              *rfact*tmask(ji,jj,jk+1)
!
         sinksil(ji,jj,jk+1) = xvsink*trn(ji,jj,jk,jpdsi) &
     &           /rjjss*rfact*tmask(ji,jj,jk+1)
!
         sinkcal(ji,jj,jk+1) = xvsink*trn(ji,jj,jk,jpcal) &
     &           /rjjss*rfact*tmask(ji,jj,jk+1)
          END DO
        END DO
      END DO
!
!  Exchange between organic matter compartments due to
!  coagulation/disaggregation
!  ---------------------------------------------------
!
      DO jk = 1, jpk-1
        DO jj = 2, nlcj-1
          DO ji = 2, nlci-1
!
!    Part I : Coagulation dependent on turbulence
!    ----------------------------------------------
!
       xagg1=rn_ag1poc/rjjss*rfact*min(avt(ji,jj,jk)/5.E-4,1.)* &
     &       trn(ji,jj,jk,jppoc)**2
       xagg2=rn_ag2poc/rjjss*rfact*min(avt(ji,jj,jk)/5.E-4,1.)* &
     &       trn(ji,jj,jk,jppoc)*trn(ji,jj,jk,jpgoc)
!
!    Aggregation of small into large particles
!    Part II : Differential settling
!    -------------------------------------------------------------------
!
       xagg3=rn_ag3poc/rjjss*rfact*                  &
     &       trn(ji,jj,jk,jppoc)*trn(ji,jj,jk,jpgoc)
       xagg4=rn_ag4poc/rjjss*rfact* &
     &       trn(ji,jj,jk,jppoc)**2
       xagg(ji,jj,jk)=xagg1+xagg2+xagg3+xagg4
       xaggfe(ji,jj,jk)=xagg(ji,jj,jk)*trn(ji,jj,jk,jpsfe)/        &
     &                  (trn(ji,jj,jk,jppoc)+rtrn)*tmask(ji,jj,jk)
!
!     Aggregation of DOC to small particles
!     --------------------------------------
!
        xaggdoc(ji,jj,jk)=(rn_ag5doc*trn(ji,jj,jk,jpdoc)               &
     & +1E3*trn(ji,jj,jk,jppoc))/rjjss*rfact                           &
     & *min(avt(ji,jj,jk)/5.E-4,1.)*trn(ji,jj,jk,jpdoc)*tmask(ji,jj,jk)
        xaggdoc2(ji,jj,jk)=rn_ag6doc*trn(ji,jj,jk,jpgoc)*rfact &
     & /rjjss*min(avt(ji,jj,jk)/5.E-4,1.)*trn(ji,jj,jk,jpdoc)  &
     & *tmask(ji,jj,jk)
          END DO
        END DO
      END DO
      DO jk = 1, jpk-1
        DO jj = 2, nlcj-1
          DO ji = 2, nlci-1
!
!     TOC remineralization. Depends on temperature and nutrients
!     ------------------------------------------------------------------
!
            zdenom=rn_kmobac-rn_grmbac+rn_gbadoc*trn(ji,jj,jk,jpdoc) &
     &        +rn_gbapoc*trn(ji,jj,jk,jppoc) &
     &        +rn_gbagoc*trn(ji,jj,jk,jpgoc)
            remik=rn_grabac/rjjss*rfact*tmask(ji,jj,jk) &
     &        *tgfunc(ji,jj,jk,jpdia+jppft) &
     &        *(trno2(ji,jj,jk)+3.E-6)/(10.E-6+trno2(ji,jj,jk)) &
     &        *trn(ji,jj,jk,jpbac)
!
! remineralization of DOC
!
            olimi(ji,jj,jk) =remik*(rn_gbadoc*trn(ji,jj,jk,jpdoc) -   &
     &                              rn_gbadoc/ztpbac*rn_grmbac)/zdenom
            morbac(ji,jj,jk)=min(olimi(ji,jj,jk),0.)*(-1.)
            olimi(ji,jj,jk) =max(olimi(ji,jj,jk),0.)
!
! remineralization of POC
!
            orem(ji,jj,jk)  =remik*(rn_gbapoc*trn(ji,jj,jk,jppoc) -   &
     &                              rn_gbapoc/ztpbac*rn_grmbac)/zdenom
            morbac(ji,jj,jk)=morbac(ji,jj,jk) + min(orem(ji,jj,jk),0.)*(-1.)
            orem(ji,jj,jk)  =max(orem(ji,jj,jk),0.)
!
! remineralization of GOC
!
            orem2(ji,jj,jk) =remik*(rn_gbagoc*trn(ji,jj,jk,jpgoc) -   &
     &                              rn_gbagoc/ztpbac*rn_grmbac)/zdenom
            morbac(ji,jj,jk)=morbac(ji,jj,jk) + min(orem2(ji,jj,jk),0.)*(-1.)
            orem2(ji,jj,jk) =max(orem2(ji,jj,jk),0.)
!
! remineralization of Iron in POC and GOC
!
            ofer(ji,jj,jk)  =remik*(rn_gbapoc*trn(ji,jj,jk,jpsfe) -   &
     &                              rn_gbapoc/ztpbac*rn_grmbac)/zdenom
            ofer(ji,jj,jk)  =max(ofer(ji,jj,jk),0.)
!
            ofer2(ji,jj,jk) =remik*(rn_gbagoc*trn(ji,jj,jk,jpbfe) -   &
     &                              rn_gbagoc/ztpbac*rn_grmbac)/zdenom
            ofer2(ji,jj,jk) =max(ofer2(ji,jj,jk),0.)

!
            bactge(ji,jj,jk)=rn_ggebac-rn_ggtbac*tn(ji,jj,jk)
!
! Fe that is taken up by bacteria minus what is available in
! DOFe, sPOFe and bPOFe
!
            bacfer=bactge(ji,jj,jk)*ferat3*(olimi(ji,jj,jk)             &
     &        +orem(ji,jj,jk)+orem2(ji,jj,jk))                          &
     &        -ofer(ji,jj,jk)-ofer2(ji,jj,jk)
!
! If there is not enough Fe in DOFe, sPOFe and bPOFe, then take up dissolved Fe
!
            ubafer(ji,jj,jk)=max(bacfer*trn(ji,jj,jk,jpfer)/            &
     &        (trn(ji,jj,jk,jpfer)+rn_kmfbac),0.)
!
! If there is not enough dissolved Fe, then decrease ggebac
!
            bactge(ji,jj,jk)=min(bactge(ji,jj,jk),                      &
     &        (ubafer(ji,jj,jk)+ofer(ji,jj,jk)+ofer2(ji,jj,jk))         &
     &        /max((olimi(ji,jj,jk)+orem(ji,jj,jk)+orem2(ji,jj,jk))     &
     &        *ferat3,minfer))
!
! Fe in excess of that taken up by bacteria
!
            rbafer(ji,jj,jk)=max(-bacfer,0.)
            resbac(ji,jj,jk) = rn_resbac*(rn_retbac**tn(ji,jj,jk)) &
     &        /rjjss*rfact*max(trn(ji,jj,jk,jpbac)-1e-10,0.)*tmask(ji,jj,jk)
!
!     Remineralisation rate of BSi dependent on T and O2
!     --------------------------------------------------
!
          siremin=min(1.32E16*exp(-11200./(273.15+tn(ji,jj,jk)))       &
     &      ,0.1)/rjjss*rfact*tmask(ji,jj,jk) &
     &      *(trno2(ji,jj,jk)+3.E-6)/(10.E-6+trno2(ji,jj,jk))
         osil(ji,jj,jk)=siremin*trn(ji,jj,jk,jpdsi)

!
!     scavenging rate of iron based on Parekh et al., GBC 2005 as implemented by 
!     Aumont & Bopp GBC 2006
!     -------------------------------------------------------------------------
!
         xkeq    = 10**(17.27 - 1565.7 / ( 273.15 + tn(ji,jj,jk) +         &
     &              (1.-tmask(ji,jj,jk))*20. ) )

         xfeequi = (-(1.+ligfer(jj,jk)*xkeq-xkeq*trn(ji,jj,jk,jpfer))+            &
     &             ((1.+ligfer(jj,jk)*xkeq-xkeq*trn(ji,jj,jk,jpfer))**2           &
     &             +4.*trn(ji,jj,jk,jpfer)*xkeq)**0.5)/(2.*xkeq)
         xlam1b  = rn_scmfer+rn_scofer*(trn(ji,jj,jk,jppoc)+trn(ji,jj,jk,jpgoc) &
     &             +trn(ji,jj,jk,jpcal)+trn(ji,jj,jk,jpdsi))*1E6

         xscave(ji,jj,jk) = xfeequi*xlam1b/rjjss*rfact*tmask(ji,jj,jk)
         scabfe(ji,jj,jk) = 1./(trn(ji,jj,jk,jppoc)+trn(ji,jj,jk,jpgoc)    &
     &                + trn(ji,jj,jk,jpdsi) + trn(ji,jj,jk,jpcal) + rtrn )
         scasfe(ji,jj,jk) = xscave(ji,jj,jk)*trn(ji,jj,jk,jppoc)/scabfe(ji,jj,jk)
         scabfe(ji,jj,jk) = xscave(ji,jj,jk)*trn(ji,jj,jk,jpgoc)/scabfe(ji,jj,jk)
!
!     Bacterial production and degradation of DMS(Pd)
!
!	 zbldmd=min(1., &
!     &         max(0.66,1.-(etot(ji,jj,jk)/rn_etomax)**6.+0.18))
!	 xlibad=min(xlimbac(ji,jj,jk),trn(ji,jj,jk,jpdmd)/      &
!     &         (trn(ji,jj,jk,jpdmd)+rn_xkdmd))                 &
!     &         * zbldmd
!
! cleavage of dmspd
!
!         xcldmd=rn_xcldmd*rfact/rjjss*trn(ji,jj,jk,jpdmd)
!
!         degdmd(ji,jj,jk)= 2*rn_grabac*xlibad  &
!     &    *1.12**(tn(ji,jj,jk))*2.*trn(ji,jj,jk,jpbac) &
!     &    * rfact/rjjss *trn(ji,jj,jk,jpdmd)
!
!         dmddms(ji,jj,jk)=rn_dmsyld*degdmd(ji,jj,jk)+xcldmd
!         degdmd(ji,jj,jk)=degdmd(ji,jj,jk)+xcldmd
!         xlibas=min(xlimbac(ji,jj,jk), trn(ji,jj,jk,jpdms)/ &
!     &       (trn(ji,jj,jk,jpdms)+rn_xkdms)) &
!     &         * zbldmd
!
! photolysis of dms
!
!         degdms(ji,jj,jk)=2*(rn_grabac*xlibas  &
!     &        *1.12**(tn(ji,jj,jk))*0.6*trn(ji,jj,jk,jpbac) &
!     &        +rn_xpodms*etot(ji,jj,jk))*rfact/rjjss*trn(ji,jj,jk,jpdms)
          END DO
        END DO
      END DO
#endif
      RETURN
      END
