MODULE trclsm
   !!======================================================================
   !!                      ***  MODULE trclsm  ***
   !! TOP :   initialisation of some run parameters for PlankTOM bio-model
   !!======================================================================
   !! History :   2.0  !  2007-12  (C. Ethe, G. Madec) Original code
   !!----------------------------------------------------------------------
#if defined key_top
   !!----------------------------------------------------------------------
   !!   'key_top'   :                                        model
   !!----------------------------------------------------------------------
   !! trc_lsm      : model initialisation
   !!----------------------------------------------------------------------
   USE oce_trc
   USE sms
   USE trc
   USE trp_trc
   USE trctrp_lec
   USE in_out_manager    ! I/O manager
   USE trdmld_trc_oce




   IMPLICIT NONE
   PRIVATE

   PUBLIC   trc_lsm   ! called by trclsm.F90 module

   !!----------------------------------------------------------------------
   !! NEMO/TOP 2.0 , LOCEAN-IPSL (2007) 
   !! $Id: trclsm_my_trc.F90 1162 2008-07-02 09:33:33Z cetlod $ 
   !! Software governed by the CeCILL licence (modipsl/doc/NEMO_CeCILL.txt)
   !!----------------------------------------------------------------------

CONTAINS

   SUBROUTINE trc_lsm
      !!----------------------------------------------------------------------
      !!                     ***  trc_lsm  ***  
      !!
      !! ** Purpose :   echo contents of namelist.trc.sms. 
      !!      Separated from reading
      !!      so phytoplankton names from namelist_top can be used
      !!
      !!         
      !!----------------------------------------------------------------------
      !!----------------------------------------------------------------------
      !
      INTEGER ::  jl
     

      IF(lwp) THEN
          WRITE(numout,*) ' '
          WRITE(numout,*) 'natagg'
          WRITE(numout,*) ' '
          WRITE(numout,*) ' aggregation term 1 (rn_ag1poc) =', rn_ag1poc
          WRITE(numout,*) ' aggregation term 2 (rn_ag2poc) =', rn_ag2poc
          WRITE(numout,*) ' aggregation term 3 (rn_ag3poc) =', rn_ag3poc
          WRITE(numout,*) ' aggregation term 4 (rn_ag4poc) =', rn_ag4poc
          WRITE(numout,*) ' aggregation term 5 (rn_ag5doc) =', rn_ag5doc
          WRITE(numout,*) ' aggregation term 6 (rn_ag6doc) =', rn_ag6doc
          WRITE(numout,*) ' POC sinking speed (rn_snkpoc)  =', rn_snkpoc
          WRITE(numout,*) ' Big particles sinking multiplication (rn_snkgoc) =', rn_snkgoc
          WRITE(numout,*) ' Big particles sinking division (rn_singoc) =', rn_singoc
!
          WRITE(numout,*) ' '
          WRITE(numout,*) 'natriv'
          WRITE(numout,*) ' '
          WRITE(numout,*) ' river conversion of dic (rn_rivdic) =', rn_rivdic
          WRITE(numout,*) ' river conversion of doc (rn_rivdoc) =', rn_rivdoc
          WRITE(numout,*) ' river conversion of fer (rn_rivfer) =', rn_rivfer
          WRITE(numout,*) ' river conversion of nit (rn_rivnit) =', rn_rivnit
          WRITE(numout,*) ' river conversion of po4 (rn_rivpo4) =', rn_rivpo4
          WRITE(numout,*) ' river conversion of poc (rn_rivpoc) =', rn_rivpoc
          WRITE(numout,*) ' river conversion of sil (rn_rivsil) =', rn_rivsil
!
          WRITE(numout,*) ' '
          WRITE(numout,*) 'natfer'
          WRITE(numout,*) ' '
          WRITE(numout,*) ' solubility of iron in dust (rn_fersol) =', rn_fersol
          WRITE(numout,*) ' coastal release of iron (rn_sedfer) =', rn_sedfer
          WRITE(numout,*) ' scavenging rate of iron (rn_scofer) =', rn_scofer
          WRITE(numout,*) ' minimum scavenging rate of iron (rn_scmfer) =', rn_scmfer
          WRITE(numout,*) ' ligand concentration of iron (rn_ligfer) =', rn_ligfer
!
          WRITE(numout,*) ' '
          WRITE(numout,*) 'natbio'
          WRITE(numout,*) ' '
          WRITE(numout,*)&
     &        ' calcification:photosynthesis coccolithoph. =', rn_coccal
          WRITE(numout,*)&
     &        ' calcite dissolution with biological loss   =', rn_discal
          WRITE(numout,*)&
     &        ' calcite dissolution half saturation        =', rn_lyscal
          WRITE(numout,*)&
     &        ' exudation rate of microzooplankton         =', rn_resmic
          WRITE(numout,*)&
     &        ' temp. dep. microzooplankton respiration    =', rn_retmic
          WRITE(numout,*)&
     &        ' fraction of microzoo exudation as PO4      =', rn_sigmic
          WRITE(numout,*)&
     &        ' efficiency of microzoo growth              =', rn_ggemic
          WRITE(numout,*)&
     &        ' temperature-dependence of microzoo gge (rn_ggtmic)   =', rn_ggtmic
          WRITE(numout,*)&
     &        ' maximal microzoo grazing rate              =', rn_gramic
          WRITE(numout,*)&
     &        ' temperature dependance growth rate microz  =',rn_mutpft(jpmic)
          WRITE(numout,*)&
     &        ' half sturation constant for micro grazing  =', rn_grkmic
          WRITE(numout,*)&
     &        ' threshold for micro grazing                =', rn_grmmic
          WRITE(numout,*) ' microzoo preference for bacteria           =', rn_gmibac
          WRITE(numout,*) ' microzoo preference for POM                =', rn_gmipoc
          WRITE(numout,*) ' microzoo preference for GOM                =', rn_gmigoc
          WRITE(numout,*)&
     &        ' non assimilated fraction of phyto by miczoo=', rn_unamic

          WRITE(numout,*)&
     &        ' respiration rate of mesozooplankton        =', rn_resmes
          WRITE(numout,*)&
     &        ' temp. dep. mesozooplankton respiration     =', rn_retmes
          WRITE(numout,*)&
     &        ' fraction of mesozoo respiration as PO4     =', rn_sigmes
          WRITE(numout,*)&
     &        ' mesozooplankton mortality rate             =', rn_mormes
          WRITE(numout,*)&
     &        ' temp. dep. mesozooplankton mortality rate  =', rn_motmes
!         WRITE(numout,*)&
!    &        ' k-half of mesozooplankton mortality rate  =', rn_mokmes
          WRITE(numout,*)&
     &        ' efficiency of mesozoo growth               =', rn_ggemes
          WRITE(numout,*)&
     &        ' maximal mesozoo grazing rate               =', rn_grames

          WRITE(numout,*)&
     &        ' temperature dependance growth rate mesozoo =',rn_mutpft(jpmes)
          WRITE(numout,*)&
     &        ' half sturation constant for meso grazing   =', rn_grkmes
          WRITE(numout,*)&
     &        ' threshold for meso grazing                 =', rn_grmmes
!
          WRITE(numout,*) ' mesozoo preference for bacteria (rn_gmebac)=', rn_gmebac
          WRITE(numout,*) ' mesozoo preference for POC      (rn_gmepoc)=', rn_gmepoc
          WRITE(numout,*) ' mesozoo preference for GOC      (rn_gmegoc)=', rn_gmegoc
          WRITE(numout,*) ' mesozoo preference for microzoo (rn_gmemic)=', rn_gmemic
!
          WRITE(numout,*)&
     &        ' mesozoo fecal pellet production            =', rn_unames

          WRITE(numout,*)&
     &        ' respiration rate of macrozooplankton       =', rn_resmac
          WRITE(numout,*)&
     &        ' temp. dep. macrozooplankton respiration    =', rn_retmac
          WRITE(numout,*)&
     &        ' fraction of macrozoo respiration as PO4    =', rn_sigmac
          WRITE(numout,*)&
     &        ' macrozooplankton mortality rate            =', rn_mormac
          WRITE(numout,*)&
     &        ' temp. dep. macrozooplankton mortality rate =', rn_motmac
!         WRITE(numout,*)&
!    &        ' k-half of macrozooplankton mortality rate =', rn_mokmac
          WRITE(numout,*)&
     &        ' efficiency of macrozoo growth              =', rn_ggemac
          WRITE(numout,*)&
     &        ' maximal macrozoo grazing rate              =', rn_gramac

          WRITE(numout,*)&
     &        ' temperature dependance growth rate macroz  =',rn_mutpft(jpmac)
          WRITE(numout,*)&
     &        ' half sturation constant for macro grazing  =', rn_grkmac
          WRITE(numout,*) ' threshold for mac grazing                  =', rn_grmmac
!
          WRITE(numout,*) ' macrozoo preference for bacteria           =', rn_gmabac
          WRITE(numout,*) ' macrozoo preference for POC                =', rn_gmapoc
          WRITE(numout,*) ' macrozoo preference for GOC                =', rn_gmagoc
          WRITE(numout,*) ' macrozoo preference for microzoo           =', rn_gmamic
          WRITE(numout,*) ' macrozoo preference for mesozoo            =', rn_gmames
!
          WRITE(numout,*) ' macrozoo fecal pellet production           =', rn_unamac
          WRITE(numout,*) ' macrozoo growth enhancement under ice (rn_icemac)=', rn_icemac
          WRITE(numout,*) ' fraction of macrozoo transported (rn_trnmac)=', rn_trnmac
          WRITE(numout,*) ' fraction of grazing reduction in coas (rn_coazoo)=', rn_coazoo

          WRITE(numout,*) ' maximum growth rate bacteria (rn_grabac)   =',rn_grabac
          WRITE(numout,*) ' temperature depend. growth bacteria (rn_mutpft) =',rn_mutpft(jpdia+jppft)
          WRITE(numout,*) ' Fe half-sat. of bacteria (rn_kmfbac)       =', rn_kmfbac
          WRITE(numout,*) ' DOC half-sat. of bacteria (rn_kmobac)      =', rn_kmobac
          WRITE(numout,*) ' PO4 half-sat. of bacteria (rn_kmpbac)      =', rn_kmpbac
          WRITE(numout,*) ' threshold for bacterial uptake (rn_grmbac) =', rn_grmbac
          WRITE(numout,*) ' bacteria preference for DOC, GOC, POC      =', rn_gbadoc,rn_gbagoc,rn_gbapoc
          WRITE(numout,*) ' bacteria growth efficiency and T depend.   =', rn_ggebac,rn_ggtbac
          WRITE(numout,*) ' bacteria respiration rate and T depend.    =', rn_resbac,rn_retbac
          WRITE(numout,*) ' bacterial fractionation for O18            =', rn_faco18
          WRITE(numout,*) ' dnsmin                          =', dnsmin
          WRITE(numout,*) ' silicon half saturation constant           =', rn_sildia
          WRITE(numout,*) ' half saturation constant for Si/C          =', rn_kmsbsi
          WRITE(numout,*) ' aggregation of phytoplankton during blooms rn_aggphy =', rn_aggphy
          WRITE(numout,*) ' fraction of phyto mort into DOM rn_tordoc =',rn_tordoc
!
        DO jl = jpdia, jpdia+jppft-1
          WRITE(numout,*) ctrcnm(jl)
          WRITE(numout,*) ' NO3 half saturation concentrat.        =',rn_kmnphy(jl)
          WRITE(numout,*) ' NH4 half saturation concentrat.        =',rn_kmhphy(jl)
          WRITE(numout,*) ' phosphate half saturation concentration=',rn_kmpphy(jl)
          WRITE(numout,*) ' phyto respiration as a fraction of growth rn_resphy =', rn_resphy(jl)
          WRITE(numout,*) ' excretion ratio                     =',rn_docphy(jl)
          WRITE(numout,*) ' maximum DOC excretion ratio (rn_domphy) =',rn_domphy(jl)
          WRITE(numout,*) ' maximum growth rate                 =',rn_mumpft(jl)
          WRITE(numout,*) ' temperature dependance growth rate  =',rn_mutpft(jl)
          WRITE(numout,*) ' microzoo preference for phyto       =',rn_gmiphy(jl)
          WRITE(numout,*) ' mesozoo preference for phytoplankton=',rn_gmephy(jl)
          WRITE(numout,*) ' macrozoo preference for phyto       =',rn_gmaphy(jl)

        END DO
        WRITE(numout,*) ' fraction of growth rate during N2fix =',rn_munfix
        WRITE(numout,*) ' threshold for nutrient uptake for P, N, and Si rn_nutthe =',rn_nutthe
!
! Fe quota model
!
        WRITE(numout,*) ' '
        WRITE(numout,*) 'natquo'
        WRITE(numout,*) ' '
        DO jl = jpdia, jpdia+jppft-1
          WRITE(numout,*) ctrcnm(jl)
          WRITE(numout,*)' iron half saturation conc. (rn_kmfphy)        =',rn_kmfphy(jl)
          WRITE(numout,*)' threshold for nutrient uptake for Fe (rn_rhfphy) =', rn_rhfphy(jl)
          WRITE(numout,*)' maximum quota for Fe (rn_qmaphy)        =',rn_qmaphy(jl)
          WRITE(numout,*)' minimum quota for Fe (rn_qmiphy)        =',rn_qmiphy(jl)
          WRITE(numout,*)' optimal quota for Fe (rn_qopphy)        =',rn_qopphy(jl)
        ENDDO
!
! Light model
!
        WRITE(numout,*) ' '
        WRITE(numout,*) 'natlit'
        WRITE(numout,*) ' '
        WRITE(numout,*) ' red light absorption coeff. of water       =', rn_ekwred
        WRITE(numout,*) ' green light absorption coeff. of water     =', rn_ekwgrn
        DO jl = jpdia, jpdia+jppft-1
          WRITE(numout,*) ctrcnm(jl)
          WRITE(numout,*) ' initial slope PI curve rn_alpphy       =',rn_alpphy(jl)
          WRITE(numout,*) ' maximum chl:C ratio rn_thmphy          =',rn_thmphy(jl)
          WRITE(numout,*) ' light absorption in the red rn_krdphy  =',rn_krdphy(jl)
          WRITE(numout,*) ' light absorption in the blue-green rn_kgrphy =',rn_kgrphy(jl)
          WRITE(numout,*) ' threshold by phytopl. for light rn_tliphy =', rn_tliphy(jl)
        ENDDO
!
! dms
!
        WRITE(numout,*) ' '
        WRITE(numout,*) 'natdms'
        WRITE(numout,*) ' '
        WRITE(numout,*)&
     &       ' Ratio of DMS/DMSP released during grazing =',rn_rdddms
        WRITE(numout,*)&
     &       ' DMSP-lyase DMSPd cleavage rate =',rn_xcldmd
        WRITE(numout,*)&
     &       ' microbial yield for DMS production =',rn_dmsyld
        WRITE(numout,*)&
     &       ' half saturation constant for bacteria on DMSPd =',rn_xkdmd
        WRITE(numout,*)&
     &       ' half saturation constant for bacteria on DMS =',rn_xkdms
        WRITE(numout,*)&
     &      ' % of DMSP in mesozoo fecal pellets lost    =', rn_assdms(1)
        WRITE(numout,*)&
     &      ' % of DMSP in macrozoo fecal pellets lost    =', rn_assdms(2)

        WRITE(numout,*)&
     &       ' maximum surface insolation =',rn_etomax
        DO jl = jpdia, jpdia+jppft-1
          WRITE(numout,*) ctrcnm(jl)
          WRITE(numout,*)&
     &        ' mean DMSP/C cell ratio rn_rphdmd =', rn_rphdmd(jl)
          WRITE(numout,*)&
     &        ' DMSP leakage coefficient rn_xpldmd =', rn_rphdmd(jl)
        ENDDO
        WRITE(numout,*) ' '
        WRITE(numout,*) 'natn2o'
        WRITE(numout,*)&
     &       ' start level diagnostic N2O nn_deun2s =', nn_deun2s
        WRITE(numout,*)&
     &       ' diagnostic N2O rn_aoun2o,rn_aoun2s,rn_atmn2o,rn_betn2s =',rn_aoun2o,rn_aoun2s,rn_atmn2o,rn_betn2s
        WRITE(numout,*)&
     &       ' prognostic N2O rn_decn2s,rn_degn2o,rn_denn2o =',rn_decn2s,rn_degn2o,rn_denn2o
        WRITE(numout,*)&
     &       ' prognostic N2O rn_doxn2o,rn_lign2o,rn_nitnh4,rn_omxn2s =',rn_doxn2o,rn_lign2o,rn_nitnh4,rn_omxn2s
        WRITE(numout,*)&
     &       ' N2A rn_degn2a,rn_denn2a =',rn_degn2a,rn_denn2a
        WRITE(numout,*)&
     &       ' Farias N2O rn_degn2b,rn_denn2b =',rn_degn2b,rn_denn2b
        WRITE(numout,*)&
     &       ' N2C rn_degn2c,rn_denn2c =',rn_degn2c,rn_denn2c
        WRITE(numout,*)&
     &       ' N2D rn_degn2d,rn_denn2d =',rn_degn2d,rn_denn2d
        WRITE(numout,*)&
     &       ' N2E rn_degn2e,rn_denn2e =',rn_degn2e,rn_denn2e
      !
      ENDIF
   END SUBROUTINE trc_lsm
   
#else
   !!----------------------------------------------------------------------
   !!  Dummy module :                                             No MY_TRC
   !!----------------------------------------------------------------------
CONTAINS
   SUBROUTINE trc_lsm                     ! Empty routine
   END  SUBROUTINE  trc_lsm
#endif  

   !!======================================================================
END MODULE trclsm
